(*  :Title:	Matlab Script Generator	 *)

(*  :Authors:   Brian L. Evans and Niranjan Damera-Venkata *)

(*
    :Summary:   To generate Matlab scripts to run the numerical optimization
 *)

(*  :Context:   FilterOptimization`Generator`  *)

(*  :PackageVersion:  FOP 1.1   @(#)Generator.m	1.21     06/21/98  *)

(*
   :Copyright:

Copyright (c) 1993-1997 The Regents of the University of California.
All rights reserved.

Permission is hereby granted, without written agreement and without
license or royalty fees, to use, copy, modify, and distribute this
software and its documentation for any purpose, provided that the above
copyright notice and the following two paragraphs appear in all copies
of this software.

IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY 
FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES 
ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF 
THE UNIVERSITY OF CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF 
SUCH DAMAGE.

THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE
PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
CALIFORNIA HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
ENHANCEMENTS, OR MODIFICATIONS.
 *)

(*  :History:   *)

(*  :Keywords:  *)

(*  :Source:    *)

(*  :Warning:   *)

(*  :Mathematica Version:  2.0  *)

(*  :Limitation:  *)

(*  :Discussion: *)

(*  :Functions: *)


(*  B E G I N     P A C K A G E  *)

BeginPackage [	"FilterOptimization`Generator`",
		"FilterOptimization`CodeGen`",
		"FilterOptimization`Filters`",
		"FilterOptimization`CostMeasures`"  ]

(*  U S A G E     I N F O R M A T I O N  *)

bestcost::usage =
"reserved variable for code generation.";

bestroot::usage =
"reserved variable for code generation.";

eps::usage =
"reserved variable for code generation.";

errvec::usage =
"reserved variable for code generation.";

f::usage =
"reserved variable for code generation.";

g::usage =
"reserved variable for code generation.";

gf::usage =
"reserved variable for code generation.";

GC::usage =
"reserved variable for code generation.";

int1::usage =
"reserved variable for code generation.";

int2::usage =
"reserved variable for code generation.";

int3::usage =
"reserved variable for code generation.";

int4::usage =
"reserved variable for code generation.";

options::usage =
"reserved variable for code generation.";

poleloc::usage =
"reserved variable for code generation.";

root::usage =
"reserved variable for code generation.";

tpa::usage =
"reserved variable for code generation.";

tpc::usage =
"reserved variable for code generation.";

wc::usage =
"reserved variable for code generation.";

wc1::usage =
"reserved variable for code generation.";

wc2::usage =
"reserved variable for code generation.";

x::usage =
"reserved variable for code generation.";

x0::usage =
"reserved variable for code generation.";

MatlabOptimizationGen::usage =
"MatlabOptimizationGen[ weights, {a, b}, {c, d}, n, m, {wp, ws, wmax},
{dp, ds, maxO}, userDer ] generates three Matlab function files and
one Matlab script \"go.m\" to run the numerical optimization.
The weights is a list of six weights that weight the difference
in magnitude response in the passband, transition band, and stopband,
the difference in phase response, the filter quality, and the
overshoot.
The arguments a and b correspond to the names of the vectors
that will hold the real and imaginary locations of the poles.
The vectors will be of length n, the number of pole pairs.
The argument wmax is the frequency that is large enough to be
considered infinite.
The arguments {dp, ds, maxO} constrain the magnitude response in the
passband, the magnitude response in the stopband, and the maximum
value of the overshoot.";

(*  E N D     U S A G E     I N F O R M A T I O N  *)

Begin[ "`Private`" ]

MatlabOptimizationGen::toosmall =
  "The number of pole pairs (``) is too small-- it needs to be at least ``.";

(*  S U P P O R T I N G     F U N C T I O N S  *)

(* filterorder --  for a Butterworth filter [Ludeman, p. 131] *)
filterorder[ wp_, ws_, dp_, ds_ ] :=
	Block [	{K1, K2},
		K1 = 20 Log[10, 1 - dp];
		K2 = 20 Log[10, ds];
		Log[10, (10^(-K1/10) - 1) / (10^(-K2/10) - 1)] /
		  (2 Log[10, wp/ws]) ]

(* getVariables *)
getvariables[x_] := Union[ Select[ Level[x, Infinity], variableQ ] ]

(* imagPartButtPole *)
imagPartButtPole[ j_, n_ ] := Sin[ Pi (3/2 -  (2 j - 1)/(2 n))]

(* myD ---  a kludge to make integrate work with D *)
myD[ x_, a_ ] :=
	Block [	{derivative, int, i, newx, rules},
		i = 0;
		rules = {};
		checkIn[ e_, w_ ] :=
			Block [	{fder, newint},
				i = i + 1;
				fder = D[e, a];
				newint = integrate[fder, w];
				AppendTo[rules, (int[i]')[a] -> newint];
				int[i][a] ];
		newx = x /.
			{ g_ integrate[ f_, w_ ] :> checkIn[f g, w],
			  integrate[f_, w_] :> checkIn[f, w] };
		derivative = D[ newx, a ];
		derivative /. rules ]

(* myDfilter *)
myDfilter[x_] := If [ SameQ[Head[x], List] && Apply[SameQ, x], First[x], x ]

(* realPartButtPole *)
realPartButtPole[ j_, n_ ] := Cos[ Pi (3/2 - (2 j - 1)/(2 n))]

(*  variableQ  *)
variableQ[x_] := SameQ[ Head[x], Symbol ]


(*  A B S T R A C T I O N S     F O R     C O D E     G E N E R A T I O N  *)

(*  writeAssignment  *)
writeAssignment[ target_, file_, lhs_, rhs_ ] :=
	writeLine[ target, file, ToString[lhs], " ",
		   assignString[target], " ", ToString[rhs],
		   endString[target] ]

(* endString *)
endString[ "Fortran" ] = ""
endString[ _ ] := ";"

(* assignString *)
assignString[ _ ] := "="

(* beginComment *)
beginComment[ "Matlab" ] = "%"
beginComment[ "C" ] = "/*"
beginComment[ "Fortran" ] = "     C"

(* endComment *)
endComment[ "C" ] = "*/"
endComment[ _ ] := ""


(*  C O D E     G E N E R A T I O N  *)

(* MatlabOptimizationGen *)
MatlabOptimizationGen[ weights_List, a_Symbol, b_Symbol, c_Symbol, d_Symbol, 
                       n_, m_, wp_, ws_,
		       wmax_, maxO_, dp_, ds_, useDer_:True ] :=
	MatlabOptimizationGen[ weights, {a, b}, {c,d}, n, m, {wp, ws, wmax},
			       maxO, {dp, ds}, useDer ] 

MatlabOptimizationGen[ { Wmp_, Wmt_, Wms_, Wph_, WQ_, WO_}, {a_, b_},
 {c_, d_}, n_, m_, {wp_, ws_, wmax_}, maxO, {dp_, ds_}, useDer_:True ] :=
Module[	{augCostFun, bodyvar, ccount, constraints, costDerName, costFun,
	 costFunName, defaultValues, explanation, file, globallist, gofile,
	gstr, i, initialGuess, j, len, mc, M, mag, nn, nstr, numcon, numparams,
	 order, paramlist, passSamples, progfilename, q, qmax, reImButter,
	 spaces, startFlag, stepfilename, stepFunName, str, strlen,
	 theconstraint, tpeak, tpeakApprox, useDerFlag, wc1value, wc2value},

	(*  A.  List of parameters, their default values, and their meaning *)


	paramlist =
	    { Wmp, Wmt, Wms, Wph, WQ, WO, wp, ws, wmax, maxO, dp, ds };

	explanation = {
	  "weight on mag. response in passband",		 (* Wmp   *)
	  "weight on mag. response in transition band",		 (* Wmt   *)
	  "weight on mag. response in stopband",		 (* Wms   *)
	  "weight on deviation from linear phase",		 (* Wph   *)
	  "weight on quality factor cost",			 (* WQ    *)
	  "weight on percent overshoot cost",			 (* WO    *)
	  "end of passband frequency",				 (* wp    *)
	  "start of stopband frequency",			 (* ws    *)
	  "max. frequency for filter to exhibit linear phase",	 (* wmax  *)
	  "max. percent overshoot of the step response",	 (* maxO  *)
	  "allowable mag. error in the passband",		 (* dp    *)
	  "allowable mag. error in the stopband" };		 (* ds    *)

	(* default values are for a second-order Butterworth filter *)
	defaultValues = { 0, 0, 0, 0.1, 0, 1, 20, 30, wp, 20, 0.21, 0.31 };

        tpeak = Unique[ "tpeak" ];
	globallist = Append[ getvariables[ N[paramlist] ], tpeak ];
	costFun = weightedCosts[ { Wmp, Wmt, Wms, Wph, WQ, WO },
				 a, b, c, d, n, m, wp, ws, wmax, tpeak ];

               

	nstr = ToString[n];
     (*   mstr = ToString[m]; *) 

	useDerFlag = TrueQ[useDer];

	(* check the filter order to see if it is enough *)
	order = filterorder[wp, ws, dp, ds];
	If [ TrueQ[ (2 n) < Round[N[order]] ],
	 Message[ MatlabOptimizationGen::toosmall, n, Round[N[order]/2] ] ];


	(*  B.  Write the generated Mathematica code to file "programN.m" *)

	progfilename = ToString[ StringForm[ "program``.m", n ] ];
	file = OpenWrite[ progfilename ];
	If [ ! SameQ[file, $Failed],
	     WriteString[ file,
		"(* Code Generated by Mathematica packages ",
		"written by Brian L. Evans *)\n",
		"(* Copyright (c) 1993-1997 by the Regents of the ",
		"University of California *)\n",
		"(* All Rights Reserved. *)\n",
		"(* See the copyright file for copyright notice, *)\n",
		"(* limitation of liability, and disclaimer of ",
		"warranty provisions. *)\n" ];
	     WriteString[ file, "(* Overall Cost Function *)\n" ];
	     Write[file, InputForm[costFun] ];
	     WriteString[file, "(* Derivatives have been omitted *)\n" ];
(*
	For [ m = 1, m <= n, m++,

	      str = ToString[StringForm["(* Derivative with respect to `` *)\n",
					a[m]]];
	      WriteString[ file, str ];
	      Write[ file, InputForm[ myD[ costFun, a[m] ] ] ];
	      str = ToString[StringForm["(* Derivative with respect to `` *)\n",
					b[m]]];
	      WriteString[ file, str ];
	      Write[ file, InputForm[ myD[ costFun, b[m] ] ] ] ];
 *)
	     Close[file] ];

	Print[ "Mathematica code for the cost function is the file '",
	       progfilename, "'." ];


	(*  C.  Write the step response to a separate file.  *)

	stepFunName = "stepresp";
	stepfilename = StringJoin[ stepFunName, ".m" ];
	file = OpenWrite[ stepfilename ];
	If [ SameQ[file, $Failed], Return[$Failed] ];
	M = Unique[ "M" ];
	nn = Unique[ "n" ];
	WriteString[ file, "function f = ", stepFunName,
        "(", x, ", ",  a, ", ", b, ", ", c, ",", d, ",", M, ")\n"  ];
	WriteString[ file, "%", ToUpperCase[ stepFunName ],
		     " computes the step response of an ",
		     "analog filter with any number of pole pairs.\n",
		     "%\n",
		     "%\tThis function takes four arguments:\n",
		     "%\t  ", x, " is time\n",
		     "%\t  ", a, " are the real values of the poles\n",
		     "%\t  ", b, " are imaginary values of the poles\n",
                     "%\t  ", c, " are the real values of the zeros\n",
		     "%\t  ", c, " are imaginary values of the zeros\n",
		     "%\t  ", M, " scales the step response\n" ];
(*	WriteString[ file, nn, " = length(", a, ");\n" ]; *)
	bodyvar = MatlabCodeGen[stepResponse[a, b, c, d, n, m, x], file ];
	WriteString[ file, "f = ", M, ".*", ToString[bodyvar], ";\n" ];
	WriteString[ file, "end\n" ];

	Close[file];

	Print[ "Matlab function for the step response ",
	       "is in the file '", stepfilename, "'." ];


	(*  D.  Write Matlab cost function and constraints to "filcostN.m" *)
	costFunName = StringJoin[ "filcost", nstr ];
	file = OpenWrite[ StringJoin[ costFunName, ".m" ] ];
	If [ SameQ[file, $Failed], Return[$Failed] ];

	WriteString[ file, "function [f,g]=", costFunName, "(x)\n" ];
	WriteString[ file,
		     "% ", ToUpperCase[costFunName],
		     "(x) returns the cost function for an analog filter\n",
		     "%\n%\tx contains the real parts of the ", nstr,
		     " pole pairs concatenated with\n",
		     "%\tthe imaginary parts of the ", nstr, " pole pairs.\n",
                     "%\tfurther concatenated with the zeros.\n",
		     "%\n%\tCode Generated by Mathematica packages ",
		     "written by Brian L. Evans\n",
		     "%\tCopyright 1993 by the Regents of the ",
		     "University of California\n",
		     "\n%% Extract real and imaginary components of the ",
		     "filters's poles ", a, " +/- j ", b, "\n" ,
                     "\n%% Extract real and imaginary components of the ",
		     "filters's zeros ", c, " +/- j ", d, "\n" ];

	WriteString[ file, a, " = x(1:", nstr, ");\n" ];
	WriteString[ file, b, " = x(", ToString[n+1], ":",
		     ToString[2*n], ");\n" ];
        WriteString[ file, c, " = x(", ToString[2*n+1], ":",
		     ToString[(2*n)+m], ");\n" ];
        WriteString[ file, d, " = x(", ToString[(2*n)+m+1], ":",
		     ToString[2*(n+m)], ");\n" ];


	If [ ! SameQ[ globallist, {} ],
	     Print[ "Global variable(s) in Matlab functions:" ];
	     Print[ globallist ];
	     str = ToString[ InputForm[ globallist ] ];
	     str = StringReplace[ str, { "{" -> "", "}" -> "", "," -> "" } ];
	     gstr = StringJoin[ "global ", str, ";\n" ];
	     WriteString[ file, "\n%% Global parameters\n", gstr ] ];

	WriteString[ file, "\n%% Parameter settings\n" ];
	numparams = Length[ paramlist ];
	For [ i = 1, i <= numparams, i++,
	      WriteString[ file, "%%   ", explanation[[i]], ": ",
			   ToString[ InputForm[ paramlist[[i]] ] ], "\n" ] ];

	(*  C O M P U T E     T H E     C O N S T R A I N T S  *)

	(*  constraints need to come first in order to compute tpeak  *)

	WriteString[ file, "\n%% Code to compute the constraints\n" ];
	constraints = {};

	(*  constraints on the quality factor of each section *)
	ccount = 0;			(* constraint counter *)

	(*  1. From Firth: qmax is 10 for wp < 10 kHz and 25 for wp > 10 kHZ *)
	WriteString[ file, "\n%% Constraints on the quality factors\n" ];
	qmax = Unique[ "qmax" ];
	If [ N[wp < 2 Pi 10000],
	     WriteString[ file, qmax, " = 10;\n" ],
	     WriteString[ file, qmax, " = 25;\n" ],
	     WriteString[ file,
			  "if ", MmaToMatlab[wp], " < ", N[2 Pi 10000], "\n",
			  "   ", qmax, " = 10;\nelse\n",
			  "   ", qmax, " = 25;\nend\n" ] ];
	For [ i = 1, i <= n, i++,
	      q = qualityOneSection[a, b, i];
	      AppendTo[constraints, q - qmax];
	      str = MmaToMatlab[ q - qmax ];
	      ccount++;
	      WriteString[ file, "g(", ccount, ") = ", str, ";\n" ] ];

	(*  2. Magnitude response in passband frequencies	*)
	(*     1 - dp <= magnitude <= 1 yields two constraints; *)
	(*     eps is Matlab's distance between real numbers;	*)
	(*     it allows us to convert x <= a to x - eps < a;	*)
	(*     we don't need to check DC because its always 1	*)
	WriteString[file, "\n%% Constraints to check the passband response\n"];
	passSamples = 10;
	For [ i = 1, i <= passSamples, i++,
	      mag = magnitude[a, b, c, d, n, m, i*wp/passSamples] - 1 - eps;
	      AppendTo[ constraints, mag ];
	      ccount++;
	      WriteString[ file, "g(", ccount, ") = ",
			   MmaToMatlab[mag], ";\n" ];
	   mag = 1 - dp - magnitude[a, b, c, d, n, m, i*wp/passSamples] - eps;
	      AppendTo[ constraints, mag ];
	      ccount++;
	      WriteString[ file, "g(", ccount, ") = ",
			   MmaToMatlab[mag], ";\n" ] ]; 

	(*  3. Magnitude response at the stopband frequency wp  *)
	WriteString[ file, "\n%% Constraint to check the stopand response\n" ];
	mag = magnitude[a, b, c, d, n, m, ws] - ds - eps;
	AppendTo[ constraints, mag ];
	ccount++;
	WriteString[ file, "g(", ccount, ") = ", MmaToMatlab[mag], ";\n" ];

	(*  4. Overshoot *)
	WriteString[ file, "\n%% Constraint to check the overshoot ",
		     "of the step response\n" ];
	WriteString[ file, "%%  Overshoot is computed by maximizing ",
		     "the function ", stepFunName, "\n" ];
	Clear[j];
	WriteString[ file, tpeak, " = fmin('", stepFunName, "', ", 0, ", ",
		     MmaToMatlab[ Max[ Table[ -Pi/b[j], {j, 1, n} ] ] ],
		     ", [], ", a, ", ", b, ",", c, ",", d, ", -1);\n" ];
	AppendTo[ constraints,
		 stepResponse[a, b, c, d, n, m, tpeak] - 1 - eps - maxO/100 ];
	ccount++;
	WriteString[ file, "g(", ccount, ") = ", stepFunName,
    "(", tpeak, ", ", a, ", ", b, ",", c, ",", d, ", 1) - 1 - eps - ",
		     MmaToMatlab[maxO/100], ";\n" ];

	(*  C O M P U T E     T H E     C O S T     F U N C T I O N  *)

	(*  It uses the value of tpeak calculated in the constraint code  *)

	WriteString[ file, "\n%% Code to compute the cost function\n" ];
	bodyvar = MatlabCodeGen[costFun, file];
	WriteString[ file, "f = ", ToString[bodyvar], ";\n" ];

	debugString[ expr_ ] :=
	  StringReplace[ MmaToMatlab[expr], 
			 { "int1" -> "integrate1",
			   "int2" -> "integrate2",
			   "int3" -> "integrate3",
			   "int4" -> "integrate4" } ];

	WriteString[ file, "\n%% Debugging code\n" ];
	WriteString[ file, "global numtimes weights;\n",
		     "weights = weights + [ ",
		     debugString[ Wms*int1/
				  (ws (10^($StopbandDecades) - 1)) ], " ",
		     debugString[ Wmp*int2/wp ], " ",
		     debugString[ Wmt*int3/(ws-wp) ], " ",
		     debugString[ Wph*int4/wmax ], " ] / f;\n",
		     "numtimes = numtimes + 1;\n" ];

	WriteString[ file, "\nend\n" ];

	Close[file];

	Print[ "Matlab code for the cost function is the file '",
	       costFunName, ".m'." ];

	(*  E.  Write derivative of Matlab cost function to "costderN.m" *)

 If [ useDerFlag, 
	costDerName = StringJoin[ "costder", nstr ];
	file = OpenWrite[ StringJoin[ costDerName, ".m" ] ];
	If [ SameQ[file, $Failed], Return[$Failed] ];
	WriteString[ file, "function [gf,GC]=", costDerName, "(x)\n" ];
	WriteString[ file, "% ", ToUpperCase[costDerName],
		     " computes the gradient of the cost function\n",
		     "%\tfor an analog filter having ",
		     nstr, " complex pole pairs.\n",
		     "%\n%\tCode Generated by Mathematica packages ",
		     "written by Brian L. Evans\n",
		     "%\tCopyright 1993 by the Regents of the ",
		     "University of California\n",
		     "\n%% Extract real and imaginary components of the ",
		     "filters's poles ", a, " +/- j ", b, "\n",
                     "\n%% Extract real and imaginary components of the ",
		     "filters's zeros ", c, " +/- j ", d, "\n" ];

	WriteString[ file, a, " = x(1:", nstr, ");\n" ];
	WriteString[ file, b, " = x(", ToString[n+1], ":",
		     ToString[2*n], ");\n" ]; 
        WriteString[ file, c, " = x(", ToString[2*n+1], ":",
		     ToString[(2*n)+m], ");\n" ];
        WriteString[ file, d, " = x(", ToString[(2*n)+m+1], ":",
		     ToString[2*(n+m)], ");\n" ];


	If [ ! SameQ[ globallist, {} ],
	     WriteString[ file, "\n%% Global parameters\n", gstr ] ];

	(* Take first derivative of cost fun w/r to each free variable *)
	(* use myD; D applied to integrate returns list of 3 equal entries *)
	startFlag = First;
	tpeakApprox = peakTimeApprox[a, b, c, d, n, m];
        Print["Finished tpeakApprox"];
	WriteString[ file, "\n%% Approximate tpeak by a differentiable ",
		     "function and assign it to ", tpa, "\n" ];
	bodyvar = MatlabCodeGen[ tpeakApprox, file, startFlag ];
	WriteString[ file, tpa, " = ", bodyvar, ";\n\n" ];
 WriteString[ file, "%% Correction to approximation of tpeak is tpc\n" ];
	WriteString[ file, tpc, " = ", MmaToMatlab[tpeak/tpa], ";\n\n" ];

	augCostFun = costFun /. tpeak -> ( tpc tpeakApprox );
	startFlag = False;
	For [ mc = 1, mc <= n, mc++,
	      WriteString[ file, "\n%% Derivative for ", a, "(", mc, ")\n" ];
          bodyvar = MatlabCodeGen[ myD[augCostFun, a[mc]], file, startFlag ];
	      WriteString[ file, "gf(", mc, ") = ", bodyvar, ";\n" ];
	      WriteString[ file, "\n%% Derivative for ", b, "(", mc, ")\n" ];
	   bodyvar = MatlabCodeGen[ myD[augCostFun, b[mc]], file, startFlag ];
	      WriteString[ file, "gf(", mc + n, ") = ", bodyvar, ";\n" ] ];

  If [ m>0,   For [ mc = 1, mc <= m, mc++,
	      WriteString[ file, "\n%% Derivative for ", c, "(", mc, ")\n" ];
	   bodyvar = MatlabCodeGen[ myD[augCostFun, c[mc]], file, startFlag ];
	      WriteString[ file, "gf(",(2*n + mc), ") = ", bodyvar, ";\n" ];
	      WriteString[ file, "\n%% Derivative for ", d, "(", mc, ")\n" ];
	   bodyvar = MatlabCodeGen[ myD[augCostFun, d[mc]], file, startFlag ];
	 WriteString[ file, "gf(",(2*n + mc) + m , ") = ", bodyvar, ";\n" ] ];
       ];



	(* Take first derivative of constraints w/r to each free variable *)
	(* use myD; D applied to integrate returns list of 3 equal entries *)
	numcon = Length[ constraints ];
	WriteString[ file,
		     "\n%% Derivative of constraints on the cost function\n" ];
	For [ mc = 1, mc <= n, mc++,
	      For [ i = 1, i <= numcon, i++,
		    theconstraint = constraints[[i]] /.
		    		    tpeak -> ( tpc tpeakApprox );
		    WriteString[ file, "\n%%   First derivative w/r to ",
		    		 a, "(", mc, ") of constraint #", i, "\n" ];
		    bodyvar = MatlabCodeGen[ myD[theconstraint, a[mc]],
		    			     file, startFlag ];
		    WriteString[ file, "GC(", mc, ", ", i, ") = ",
		    		 bodyvar, ";\n" ] ] ];
	For [ mc = 1, mc <= n, mc++,
	      For [ i = 1, i <= numcon, i++,
		    theconstraint = constraints[[i]] /.
		    		    tpeak -> ( tpc tpeakApprox );
		    WriteString[ file, "\n%%   First derivative w/r to ",
		    		 b, "(", mc, ") of constraint #", i, "\n" ];
   If[m==0,   If [ (mc == n) && (i == numcon), startFlag = Last ]; ];
		    bodyvar = MatlabCodeGen[ myD[theconstraint, b[mc]],
		    			     file, startFlag ];
		    WriteString[ file, "GC(", n + mc, ", ", i, ") = ",
		    		 bodyvar, ";\n" ] ] ];



     If[m>0,  For [ mc = 1, mc <= m, mc++,
	      For [ i = 1, i <= numcon, i++,
		    theconstraint = constraints[[i]] /.
		    		    tpeak -> ( tpc tpeakApprox );
		    WriteString[ file, "\n%%   First derivative w/r to ",
		    		 c, "(", mc, ") of constraint #", i, "\n" ];
		    bodyvar = MatlabCodeGen[ myD[theconstraint, c[mc]],
		    			     file, startFlag ];
		    WriteString[ file, "GC(", (2*n + mc), ", ", i, ") = ",
		    		 bodyvar, ";\n" ] ] ];
	For [ mc = 1, mc <= m, mc++,
	      For [ i = 1, i <= numcon, i++,
		    theconstraint = constraints[[i]] /.
		    		    tpeak -> ( tpc tpeakApprox );
		    WriteString[ file, "\n%%   First derivative w/r to ",
		    		 d, "(", mc, ") of constraint #", i, "\n" ];
		    If [ (mc == m) && (i == numcon), startFlag = Last ];
		    bodyvar = MatlabCodeGen[ myD[theconstraint, d[mc]],
		    			     file, startFlag ];
		    WriteString[ file, "GC(", (2*n + mc) + m, ", ", i, ") = ",
		    		 bodyvar, ";\n" ] ] ];


          ];



	WriteString[ file, "\nend\n" ];

	Close[file];

	Print[ "Matlab function for the gradient of the cost function ",
	       "is in the file '", costDerName, ".m'." ]
]; 

	(*  E.  Generate "goN.m" file to run the simulation in Matlab *)

	gofile = StringJoin[ "go", nstr, ".m" ];
	file = OpenWrite[ gofile ];
	If [ SameQ[file, $Failed], Return[$Failed] ];
	WriteString[ file, "%% Matlab script to run the optimization\n",
		     "%% Code Generated by Mathematica packages ",
		     "written by Brian L. Evans\n",
		     "%% Copyright 1993 by the Regents of the ",
		     "University of California\n" ];

	If [ ! SameQ[globallist, {}],
	     WriteString[ file, "\n%% This program uses the following ",
			 "global variables:\n" ];
	     WriteString[ file, gstr ];
	     startFlag = True;
	     For [ i = 1, i <= numparams, i++,
		   If [ variableQ[ paramlist[[i]] ],
			If [ startFlag,
	     		     WriteString[ file, "\n%% The following constants ",
					  "have been given default values:\n" ];
			     startFlag = False ];
			str = StringJoin[ ToString[ paramlist[[i]] ], " = ",
					  ToString[ defaultValues[[i]] ] ];
			strlen = StringLength[str];
			len = Max[ 20 - strlen, 1 ];
			spaces = Apply[ StringJoin, Table[ " ", {len} ] ];
			WriteString[ file, str, ";", spaces, "%% ",
				     explanation[[i]], "\n" ] ] ];
	     WriteString[ file, "\n%% The program uses one global variable ",
			  "that is updated at each iteration:\n",
			  "%%\t", tpeak, " the time at which the peak in the",
			  " step response occurs\n" ];
	     symlist = Complement[globallist,
				  Append[Select[paramlist, variableQ], tpeak]];
	     If [ ! SameQ[ symlist, {} ],
		  Print[ "In the file '", gofile, "', you must give the ",
			 "following parameters values:" ];
		  Print[ symlist ];
		  WriteString[ file, "\n%% You must provide values ",
			       "for the following variables:\n" ];
		  Scan[ WriteString[ file, #, " = ;\n" ]&, symlist ] ] ];

	WriteString[ file, "\n%% Debugging code\n" ];
	WriteString[ file, "global numtimes weights;\n",
		     "weights = [0 0 0 0];\n",
		     "numtimes = 0;\n" ];

	WriteString[ file, "\n%% Initial Guess ", x0,
		     " is a Butterworth filter\n" ];
	WriteString[ file, "\n%% We can choose the cutoff frequency to be ",
		     "between these two frequencies:\n" ];
	wc1value = N[ wp / (-1 + 1/(1 - dp)^2)^(1/(4 n)) ];
	WriteString[ file, wc1, " = ", MmaToMatlab[wc1value], ";\n" ];
	wc2value = N[ ws / (-1 + 1/(ds)^2)^(1/(4 n)) ];
	WriteString[ file, wc2, " = ", MmaToMatlab[wc2value], ";\n" ];
	WriteString[ file, "if ", wc1, " > ", wc2, "\n" ];
	WriteString[ file, "  error( 'The filter order is too low.' );\n" ];
	WriteString[ file, "end;\n" ];
	reImButter = Table[ realPartButtPole[j, 2 n], {j, 1, n} ] ~Join~
		     Table[ imagPartButtPole[j, 2 n], {j, 1, n} ];
	WriteString[ file, "\n%% Choose the middle frequency for wc\n" ];
	WriteString[ file, wc, " = ", MmaToMatlab[(wc1 + wc2)/2], ";\n" ];
	WriteString[ file, x0, " = ", wc, "*", MmaToMatlab[reImButter], ";\n" ];
	Clear[j];
	WriteString[ file, tpeak, " = fmin( '", stepFunName, "', 0, ",
		     MmaToMatlab[ Max[ Table[ -Pi/x0[j], {j, n+1, 2 n} ] ] ],
", [], ", x0, "(1:", n, "), ",x0, "(", n+1, ":", 2 n, ")", ",", x0, 
"(", (2 n)+1, ":", (2 n)+m, ")", ",", x0, "(", (2 n)+m+1, ":", 2 (n+m),"), -1 );\n" ];

	WriteString[ file, "if ( ", stepFunName, "(", tpeak, ", ",
     x0, "(1:", n, "), ", x0, "(", n+1, ":", 2 n, "), ",x0, 
"(", (2 n)+1, ":", (2 n)+m, ")", ",", x0, "(", (2 n)+m+1, ":", 2 (n+m),")
, 1)", " - 1 ) > ", MmaToMatlab[maxO/100], "\n" ];
	WriteString[ file, "  fprintf(1, '  overshoot for the initial guess ",
		     "is higher than minimum.\\n');\n", "end\n" ];

	WriteString[ file, "%% Do 10 iterations at a time and quit ",
		     "when the first three " ];
	WriteString[ file, "%%   digits of the value of the cost function ",
		     "remain constant\n" ];
	WriteString[ file, "\noptions = foptions;\n" ];
        WriteString[ file, "options(1) = 2;\n"];
        WriteString[ file, "options(9) = 1;\n"]
	WriteString[ file, "options(14) = 100;\n" ];
	WriteString[ file, errvec, " = ",
		     MmaToMatlab[ Table[-100*eps, {2 (n+m)}] ], ";\n" ];
	WriteString[ file, "[", root, ", ", options,
		     "] = constr('", costFunName, "', ",
		     x0, ", options, [], ",
		     errvec,
		     If [ useDerFlag,
		          StringJoin[ ", '", costDerName, "'" ],
			  "" ],
		     ");\n" ];
	WriteString[ file, lastcost, " = ", costFunName, "(", x0, ")", ";\n" ];
	WriteString[ file, "while ( abs( (", lastcost, " - ",
		     options, "(8) ) / ", lastcost, ") > 1e-3 ),", "\n" ];
	WriteString[ file, "  ", lastcost, " = ", options, "(8)", ";\n" ];
	WriteString[ file, "  [", root, ", ", options,
		     "] = constr('", costFunName, "', ",
		     root, ", options, [], ",
		     errvec,
		     If [ useDerFlag,
		          StringJoin[ ", '", costDerName, "'" ],
			  "" ],
		     ");\n" ];
	WriteString[ file, "end", ";\n" ];
	WriteString[ file,
		     "disp('The conjugate zero pairs are located at:');\n" ];
	WriteString[ file, zeroloc, " = ", root, "(", (2 n)+1,":",(2 n)+m, ") +",
		     "i*", root, "(",(2 n)+m+1 , ":", 2 (n+m), ");\n" ];
	WriteString[ file, "disp(", zeroloc, ");\n" ];

        WriteString[ file,
		     "disp('The conjugate pole pairs are located at:');\n" ];
	WriteString[ file, poleloc, " = ", root, "(1:", n, ") +",
		     "i*", root, "(", n+1, ":", 2 n, ");\n" ];
	WriteString[ file, "disp(", poleloc, ");\n" ];


	WriteString[ file, "\n%% Normalized weight vector\n",
		     "weights / numtimes\n" ];
	Close[file];

	Print[ "The Matlab file '", gofile, "' will run the optimization." ];

	gofile ]

EndPackage[]
End[]

Protect[ MatlabOptimizationGen ];

Protect[ bestcost, bestroot, eps, errvec, f, g, gf, GC, int1, int2, int3,
	 int4, options, poleloc, root, tpa, tpc, wc, wc1, wc2, x, x0 ];

Null
