function [f,g]=filcost2(x)
% FILCOST2(x) returns the cost function for an analog filter
%
%	x contains the real parts of the 2 pole pairs concatenated with
%	the imaginary parts of the 2 pole pairs.
%	further concatenated with the zeros.
%
%	Code Generated by Mathematica packages written by Brian L. Evans
%	Copyright 1993 by the Regents of the University of California

%% Extract real and imaginary components of the filters's poles a +/- j b

%% Extract real and imaginary components of the filters's zeros c +/- j d
a = x(1:2);
b = x(3:4);
c = x(5:4);
d = x(5:4);

%% Global parameters
global dp ds maxO wmax Wmp Wms Wmt WO wp Wph WQ ws tpeak1;

%% Parameter settings
%%   weight on mag. response in passband: Wmp
%%   weight on mag. response in transition band: Wmt
%%   weight on mag. response in stopband: Wms
%%   weight on deviation from linear phase: Wph
%%   weight on quality factor cost: WQ
%%   weight on percent overshoot cost: WO
%%   end of passband frequency: wp
%%   start of stopband frequency: ws
%%   max. frequency for filter to exhibit linear phase: wmax
%%   max. percent overshoot of the step response: maxO
%%   allowable mag. error in the passband: dp
%%   allowable mag. error in the stopband: ds

%% Code to compute the constraints

%% Constraints on the quality factors
if wp < 62831.9
   qmax1 = 10;
else
   qmax1 = 25;
end
g(1) = -qmax1 - sqrt(a(1).^2 + b(1).^2)./(2.*a(1));
g(2) = -qmax1 - sqrt(a(2).^2 + b(2).^2)./(2.*a(2));

%% Constraints to check the passband response
g(3) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(4) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(5) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(6) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(7) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(8) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(9) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(10) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(11) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4));
g(12) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4));
g(13) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(14) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(15) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(16) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(17) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(18) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25));
g(19) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(20) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100));
g(21) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))));
g(22) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))));

%% Constraint to check the stopand response
g(23) = -ds - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2))./sqrt(((a(1).^2 + b(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(2).^2 - b(2).^2))));

%% Constraint to check the overshoot of the step response
%%  Overshoot is computed by maximizing the function stepresp
tpeak1 = fmin('stepresp', 0, max(-(pi./b(1)), -(pi./b(2))), [], a, b,c,d, -1);
%[-(pi./b(1)), -(pi./b(2))]
g(24) = stepresp(tpeak1, a, b,c,d, 1) - 1 - eps - maxO./100;

%% Code to compute the cost function
w1 = [ws:(99.*ws)./100:100.*ws];
expr25 = (a(1).^2 + b(1).^2).^2;
expr26 = ((a(1).^2 + b(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(1).^2 - b(1).^2))).^(-1);
expr27 = (a(2).^2 + b(2).^2).^2;
expr28 = ((a(2).^2 + b(2).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(2).^2 - b(2).^2))).^(-1);
expr29 = expr25.*expr26.*expr27.*expr28;
integrate1 = trapz(w1, expr29);
w2 = [0:wp./100:wp];
expr30 = a(1).^2 + b(1).^2;
expr31 = a(2).^2 + b(2).^2;
expr32 = (a(1).^2 + b(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(1).^2 - b(1).^2));
expr33 = (a(2).^2 + b(2).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(2).^2 - b(2).^2));
expr34 = -1./2;
expr35 = (-1 + expr30.*expr31.*(expr32.*expr33).^expr34).^2;
integrate2 = trapz(w2, expr35);
w3 = [wp:(-wp + ws)./100:ws];
expr36 = -(w3./(wp - ws));
expr37 = ws./(wp - ws);
expr38 = a(1).^2 + b(1).^2;
expr39 = a(2).^2 + b(2).^2;
expr40 = (a(1).^2 + b(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(1).^2 - b(1).^2));
expr41 = (a(2).^2 + b(2).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(2).^2 - b(2).^2));
expr42 = -1./2;
expr43 = (expr36 + expr37 + expr38.*expr39.*(expr40.*expr41).^expr42).^2;
integrate3 = trapz(w3, expr43);
w4 = [0:wmax./100:wmax];
expr44 = angle(1 + (i.*(w4 - b(1)))./a(1));
expr45 = angle(1 + (i.*(w4 + b(1)))./a(1));
expr46 = angle(1 + (i.*(w4 - b(2)))./a(2));
expr47 = angle(1 + (i.*(w4 + b(2)))./a(2));
expr48 = wmax.^(-3);
expr49 = 1./2;
expr50 = -2.*wmax.*a(1);
expr51 = angle(1 + (i.*(wmax - b(1)))./a(1)) + angle(1 + (i.*(wmax + b(1)))./a(1));
expr52 = -wmax.^2 - a(1).^2 + b(1).^2;
expr53 = -(a(1).*b(1).*log(1 + (wmax - b(1)).^2./a(1).^2));
expr54 = a(1).*b(1).*log(1 + (wmax + b(1)).^2./a(1).^2);
expr55 = -2.*wmax.*a(2);
expr56 = angle(1 + (i.*(wmax - b(2)))./a(2)) + angle(1 + (i.*(wmax + b(2)))./a(2));
expr57 = -wmax.^2 - a(2).^2 + b(2).^2;
expr58 = -(a(2).*b(2).*log(1 + (wmax - b(2)).^2./a(2).^2));
expr59 = a(2).*b(2).*log(1 + (wmax + b(2)).^2./a(2).^2);
expr60 = (expr44 + expr45 + expr46 + expr47 - 3.*expr48.*(expr49.*(expr50 - expr51.*expr52 + expr53 + expr54) + expr49.*(expr55 - expr56.*expr57 + expr58 + expr59)).*w4).^2;
integrate4 = trapz(w4, expr60);
expr61 = (integrate2.*Wmp)./wp;
expr62 = (integrate4.*Wph)./wmax;
expr63 = (integrate1.*Wms)./(99.*ws);
expr64 = (integrate3.*Wmt)./(-wp + ws);
expr65 = 1./2;
expr66 = sqrt((sqrt(a(1).^2 + b(1).^2).*sqrt(a(2).^2 + b(2).^2))./(a(1).*a(2)));
expr67 = b(1).^(-1);
expr68 = a(2).^2 + b(2).^2;
expr69 = ((a(1) - a(2)).^2 + (b(1) - b(2)).^2).*((a(1) - a(2)).^2 + (b(1) + b(2)).^2);
expr70 = -1./2;
expr71 = b(1).*cos(angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2))) + angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2))));
expr72 = a(1).*sin(angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2))) + angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2))));
expr73 = exp(tpeak1.*a(1));
expr74 = cos(tpeak1.*b(1));
expr75 = a(1);
expr76 = a(1).^2 + b(1).^2;
expr77 = sin(angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2))) + angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2))));
expr78 = sin(tpeak1.*b(1));
expr79 = b(2).^(-1);
expr80 = ((-a(1) + a(2)).^2 + (-b(1) + b(2)).^2).*((-a(1) + a(2)).^2 + (b(1) + b(2)).^2);
expr81 = b(2).*cos(angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2))) + angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2))));
expr82 = a(2).*sin(angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2))) + angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2))));
expr83 = exp(tpeak1.*a(2));
expr84 = cos(tpeak1.*b(2));
expr85 = a(2);
expr86 = sin(angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2))) + angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2))));
expr87 = sin(tpeak1.*b(2));
expr88 = expr67.*expr68.*expr69.^expr70.*(expr71 + expr72).*(1 - expr73.*(expr74 - expr67.*(expr75 - (expr76.*expr77)./(expr71 + expr72)).*expr78));
expr89 = expr76.*expr79.*expr80.^expr70.*(expr81 + expr82).*(1 - expr83.*(expr84 - expr79.*(expr85 - (expr68.*expr86)./(expr81 + expr82)).*expr87));
expr90 = (-0.5 + expr65.*expr66).*WQ;
expr91 = expr61 + expr62 + expr63 + expr64 + expr90 + 100.*(-1 + expr88 + expr89).^2.*WO;
f = expr91;

%% Debugging code
global numtimes weights;
weights = weights + [ (integrate1.*Wms)./(99.*ws) (integrate2.*Wmp)./wp (integrate3.*Wmt)./(-wp + ws) (integrate4.*Wph)./wmax ] / f;
numtimes = numtimes + 1;

end
