function [f,g]=filcost2(x)
% FILCOST2(x) returns the cost function for an analog filter
%
%	x contains the real parts of the 2 pole pairs concatenated with
%	the imaginary parts of the 2 pole pairs.
%	further concatenated with the zeros.
%
%	Code Generated by Mathematica packages written by Brian L. Evans
%	Copyright 1993 by the Regents of the University of California

%% Extract real and imaginary components of the filters's poles a +/- j b

%% Extract real and imaginary components of the filters's zeros c +/- j d
a = x(1:2);
b = x(3:4);
c = x(5:5);
d = x(6:6);

%% Global parameters
global dp ds maxO wmax Wmp Wms Wmt WO wp Wph WQ ws tpeak1;

%% Parameter settings
%%   weight on mag. response in passband: Wmp
%%   weight on mag. response in transition band: Wmt
%%   weight on mag. response in stopband: Wms
%%   weight on deviation from linear phase: Wph
%%   weight on quality factor cost: WQ
%%   weight on percent overshoot cost: WO
%%   end of passband frequency: wp
%%   start of stopband frequency: ws
%%   max. frequency for filter to exhibit linear phase: wmax
%%   max. percent overshoot of the step response: maxO
%%   allowable mag. error in the passband: dp
%%   allowable mag. error in the stopband: ds

%% Code to compute the constraints

%% Constraints on the quality factors
if wp < 62831.9
   qmax1 = 10;
else
   qmax1 = 25;
end
g(1) = -qmax1 - sqrt(a(1).^2 + b(1).^2)./(2.*a(1));
g(2) = -qmax1 - sqrt(a(2).^2 + b(2).^2)./(2.*a(2));

%% Constraints to check the passband response
g(3) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(1).^2 - d(1).^2)))./100))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(4) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(1).^2 - d(1).^2)))./100))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(5) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(1).^2 - d(1).^2)))./25))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(6) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(1).^2 - d(1).^2)))./25))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(7) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(8) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(9) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(10) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(11) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(1).^2 - d(1).^2)))./4))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4)));
g(12) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(1).^2 - d(1).^2)))./4))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4)));
g(13) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(14) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(15) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(16) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(17) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(18) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(19) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(20) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(21) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(1).^2 - d(1).^2))))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2)))));
g(22) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(1).^2 - d(1).^2))))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2)))));

%% Constraint to check the stopand response
g(23) = -ds - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt((c(1).^2 + d(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(c(1).^2 - d(1).^2))))./((c(1).^2 + d(1).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(2).^2 - b(2).^2)))));

%% Constraint to check the overshoot of the step response
%%  Overshoot is computed by maximizing the function stepresp
tpeak1 = fmin('stepresp', 0, max(-(pi./b(1)), -(pi./b(2))), [], a, b,c,d, -1);
g(24) = stepresp(tpeak1, a, b,c,d, 1) - 1 - eps - maxO./100;

%% Code to compute the cost function
w1 = [ws:(99.*ws)./100:100.*ws];
expr39 = (a(1).^2 + b(1).^2).^2;
expr40 = ((a(1).^2 + b(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(1).^2 - b(1).^2))).^(-1);
expr41 = (a(2).^2 + b(2).^2).^2;
expr42 = ((a(2).^2 + b(2).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(2).^2 - b(2).^2))).^(-1);
expr43 = (c(1).^2 + d(1).^2).^(-2);
expr44 = (c(1).^2 + d(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(c(1).^2 - d(1).^2));
expr45 = expr39.*expr40.*expr41.*expr42.*expr43.*expr44;
integrate1 = trapz(w1, expr45);
w2 = [0:wp./100:wp];
expr46 = a(1).^2 + b(1).^2;
expr47 = a(2).^2 + b(2).^2;
expr48 = (a(1).^2 + b(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(1).^2 - b(1).^2));
expr49 = (a(2).^2 + b(2).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(2).^2 - b(2).^2));
expr50 = -1./2;
expr51 = (c(1).^2 + d(1).^2).^(-1);
expr52 = sqrt((c(1).^2 + d(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(c(1).^2 - d(1).^2)));
expr53 = (-1 + expr46.*expr47.*(expr48.*expr49).^expr50.*expr51.*expr52).^2;
integrate2 = trapz(w2, expr53);
w3 = [wp:(-wp + ws)./100:ws];
expr54 = -(w3./(wp - ws));
expr55 = ws./(wp - ws);
expr56 = a(1).^2 + b(1).^2;
expr57 = a(2).^2 + b(2).^2;
expr58 = (a(1).^2 + b(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(1).^2 - b(1).^2));
expr59 = (a(2).^2 + b(2).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(2).^2 - b(2).^2));
expr60 = -1./2;
expr61 = (c(1).^2 + d(1).^2).^(-1);
expr62 = sqrt((c(1).^2 + d(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(c(1).^2 - d(1).^2)));
expr63 = (expr54 + expr55 + expr56.*expr57.*(expr58.*expr59).^expr60.*expr61.*expr62).^2;
integrate3 = trapz(w3, expr63);
w4 = [0:wmax./100:wmax];
expr64 = angle(1 + (i.*(w4 - b(1)))./a(1));
expr65 = angle(1 + (i.*(w4 + b(1)))./a(1));
expr66 = angle(1 + (i.*(w4 - b(2)))./a(2));
expr67 = angle(1 + (i.*(w4 + b(2)))./a(2));
expr68 = -angle(1 + (i.*(w4 - d(1)))./c(1));
expr69 = -angle(1 + (i.*(w4 + d(1)))./c(1));
expr70 = wmax.^(-3);
expr71 = 1./2;
expr72 = -2.*wmax.*a(1);
expr73 = angle(1 + (i.*(wmax - b(1)))./a(1)) + angle(1 + (i.*(wmax + b(1)))./a(1));
expr74 = -wmax.^2 - a(1).^2 + b(1).^2;
expr75 = -(a(1).*b(1).*log(1 + (wmax - b(1)).^2./a(1).^2));
expr76 = a(1).*b(1).*log(1 + (wmax + b(1)).^2./a(1).^2);
expr77 = -2.*wmax.*a(2);
expr78 = angle(1 + (i.*(wmax - b(2)))./a(2)) + angle(1 + (i.*(wmax + b(2)))./a(2));
expr79 = -wmax.^2 - a(2).^2 + b(2).^2;
expr80 = -(a(2).*b(2).*log(1 + (wmax - b(2)).^2./a(2).^2));
expr81 = a(2).*b(2).*log(1 + (wmax + b(2)).^2./a(2).^2);
expr82 = 2.*wmax.*c(1);
expr83 = angle(1 + (i.*(wmax - d(1)))./c(1)) + angle(1 + (i.*(wmax + d(1)))./c(1));
expr84 = -wmax.^2 - c(1).^2 + d(1).^2;
expr85 = c(1).*d(1).*log(1 + (wmax - d(1)).^2./c(1).^2);
expr86 = -(c(1).*d(1).*log(1 + (wmax + d(1)).^2./c(1).^2));
expr87 = -3.*expr70.*(expr71.*(expr72 - expr73.*expr74 + expr75 + expr76) + expr71.*(expr77 - expr78.*expr79 + expr80 + expr81) + expr71.*(expr82 + expr83.*expr84 + expr85 + expr86)).*w4;
expr88 = (expr64 + expr65 + expr66 + expr67 + expr68 + expr69 + expr87).^2;
integrate4 = trapz(w4, expr88);
expr89 = (integrate2.*Wmp)./wp;
expr90 = (integrate4.*Wph)./wmax;
expr91 = (integrate1.*Wms)./(99.*ws);
expr92 = (integrate3.*Wmt)./(-wp + ws);
expr93 = 1./2;
expr94 = sqrt((sqrt(a(1).^2 + b(1).^2).*sqrt(a(2).^2 + b(2).^2))./(a(1).*a(2)));
expr95 = b(1).^(-1);
expr96 = a(2).^2 + b(2).^2;
expr97 = ((a(1) - a(2)).^2 + (b(1) - b(2)).^2).*((a(1) - a(2)).^2 + (b(1) + b(2)).^2);
expr98 = -1./2;
expr99 = (c(1).^2 + d(1).^2).^(-1);
expr100 = ((a(1) - c(1)).^2 + (b(1) - d(1)).^2).*((a(1) - c(1)).^2 + (b(1) + d(1)).^2);
expr101 = b(1);
expr102 = angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2)));
expr103 = angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2)));
expr104 = -angle(1 + (i.*(b(1) - d(1)))./(a(1) - c(1)));
expr105 = -angle(1 + (i.*(b(1) + d(1)))./(a(1) - c(1)));
expr106 = a(1);
expr107 = exp(tpeak1.*a(1));
expr108 = cos(tpeak1.*b(1));
expr109 = a(1).^2 + b(1).^2;
expr110 = sin(tpeak1.*b(1));
expr111 = b(2).^(-1);
expr112 = ((-a(1) + a(2)).^2 + (-b(1) + b(2)).^2).*((-a(1) + a(2)).^2 + (b(1) + b(2)).^2);
expr113 = ((a(2) - c(1)).^2 + (b(2) - d(1)).^2).*((a(2) - c(1)).^2 + (b(2) + d(1)).^2);
expr114 = b(2);
expr115 = angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2)));
expr116 = angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2)));
expr117 = -angle(1 + (i.*(b(2) - d(1)))./(a(2) - c(1)));
expr118 = -angle(1 + (i.*(b(2) + d(1)))./(a(2) - c(1)));
expr119 = a(2);
expr120 = exp(tpeak1.*a(2));
expr121 = cos(tpeak1.*b(2));
expr122 = sin(tpeak1.*b(2));
expr123 = (-0.5 + expr93.*expr94).*WQ;
expr124 = expr100.^expr93;
expr125 = expr97.^expr98;
expr126 = expr101.*cos(expr102 + expr103 + expr104 + expr105) + expr106.*sin(expr102 + expr103 + expr104 + expr105);
expr127 = -(expr107.*(expr108 - expr110.*expr95.*(expr106 - (expr109.*sin(expr102 + expr103 + expr104 + expr105))./(expr101.*cos(expr102 + expr103 + expr104 + expr105) + expr106.*sin(expr102 + expr103 + expr104 + expr105)))));
expr128 = expr112.^expr98;
expr129 = expr113.^expr93;
expr130 = expr114.*cos(expr115 + expr116 + expr117 + expr118) + expr119.*sin(expr115 + expr116 + expr117 + expr118);
expr131 = -(expr120.*(expr121 - expr111.*expr122.*(expr119 - (expr96.*sin(expr115 + expr116 + expr117 + expr118))./(expr114.*cos(expr115 + expr116 + expr117 + expr118) + expr119.*sin(expr115 + expr116 + expr117 + expr118)))));
expr132 = expr123 + expr89 + expr90 + expr91 + expr92 + 100.*(-1 + expr109.*expr111.*expr128.*expr129.*expr130.*(1 + expr131).*expr99 + expr124.*expr125.*expr126.*(1 + expr127).*expr95.*expr96.*expr99).^2.*WO;
f = expr132;

%% Debugging code
global numtimes weights;
weights = weights + [ (integrate1.*Wms)./(99.*ws) (integrate2.*Wmp)./wp (integrate3.*Wmt)./(-wp + ws) (integrate4.*Wph)./wmax ] / f;
numtimes = numtimes + 1;

end
