function [f,g]=filcost2(x)
% FILCOST2(x) returns the cost function for an analog filter
%
%	x contains the real parts of the 2 pole pairs concatenated with
%	the imaginary parts of the 2 pole pairs.
%	further concatenated with the zeros.
%
%	Code Generated by Mathematica packages written by Brian L. Evans
%	Copyright 1993 by the Regents of the University of California

%% Extract real and imaginary components of the filters's poles a +/- j b

%% Extract real and imaginary components of the filters's zeros c +/- j d
a = x(1:2);
b = x(3:4);
c = x(5:6);
d = x(7:8);

%% Global parameters
global dp ds maxO wmax Wmp Wms Wmt WO wp Wph WQ ws tpeak1;

%% Parameter settings
%%   weight on mag. response in passband: Wmp
%%   weight on mag. response in transition band: Wmt
%%   weight on mag. response in stopband: Wms
%%   weight on deviation from linear phase: Wph
%%   weight on quality factor cost: WQ
%%   weight on percent overshoot cost: WO
%%   end of passband frequency: wp
%%   start of stopband frequency: ws
%%   max. frequency for filter to exhibit linear phase: wmax
%%   max. percent overshoot of the step response: maxO
%%   allowable mag. error in the passband: dp
%%   allowable mag. error in the stopband: ds

%% Code to compute the constraints

%% Constraints on the quality factors
if wp < 62831.9
   qmax1 = 10;
else
   qmax1 = 25;
end
g(1) = -qmax1 - sqrt(a(1).^2 + b(1).^2)./(2.*a(1));
g(2) = -qmax1 - sqrt(a(2).^2 + b(2).^2)./(2.*a(2));

%% Constraints to check the passband response
g(3) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(2).^2 - d(2).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(4) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(2).^2 - d(2).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(5) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(2).^2 - d(2).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(6) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(2).^2 - d(2).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(7) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(8) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(9) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(10) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(11) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(1).^2 - d(1).^2)))./4).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(2).^2 - d(2).^2)))./4)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4)));
g(12) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(1).^2 - d(1).^2)))./4).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(2).^2 - d(2).^2)))./4)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4)));
g(13) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(14) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(15) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(16) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(17) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(18) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25)));
g(19) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(20) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100)));
g(21) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(1).^2 - d(1).^2))).*((c(2).^2 + d(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(2).^2 - d(2).^2)))))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2)))));
g(22) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(1).^2 - d(1).^2))).*((c(2).^2 + d(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(2).^2 - d(2).^2)))))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2)))));

%% Constraint to check the stopand response
g(23) = -ds - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(c(1).^2 - d(1).^2))).*((c(2).^2 + d(2).^2).^2 + ws.^2.*(ws.^2 + 2.*(c(2).^2 - d(2).^2)))))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(2).^2 - b(2).^2)))));

%% Constraint to check the overshoot of the step response
%%  Overshoot is computed by maximizing the function stepresp
tpeak1 = fmin('stepresp', 0, max(-(pi./b(1)), -(pi./b(2))), [], a, b,c,d, -1);
g(24) = stepresp(tpeak1, a, b,c,d, 1) - 1 - eps - maxO./100;

%% Code to compute the cost function
w1 = [ws:(99.*ws)./100:100.*ws];
expr52 = (a(1).^2 + b(1).^2).^2;
expr53 = ((a(1).^2 + b(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(1).^2 - b(1).^2))).^(-1);
expr54 = (a(2).^2 + b(2).^2).^2;
expr55 = ((a(2).^2 + b(2).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(2).^2 - b(2).^2))).^(-1);
expr56 = (c(1).^2 + d(1).^2).^(-2);
expr57 = (c(1).^2 + d(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(c(1).^2 - d(1).^2));
expr58 = (c(2).^2 + d(2).^2).^(-2);
expr59 = (c(2).^2 + d(2).^2).^2 + w1.^2.*(w1.^2 + 2.*(c(2).^2 - d(2).^2));
expr60 = expr52.*expr53.*expr54.*expr55.*expr56.*expr57.*expr58.*expr59;
integrate1 = trapz(w1, expr60);
w2 = [0:wp./100:wp];
expr61 = a(1).^2 + b(1).^2;
expr62 = a(2).^2 + b(2).^2;
expr63 = (a(1).^2 + b(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(1).^2 - b(1).^2));
expr64 = (a(2).^2 + b(2).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(2).^2 - b(2).^2));
expr65 = -1./2;
expr66 = (c(1).^2 + d(1).^2).^(-1);
expr67 = (c(2).^2 + d(2).^2).^(-1);
expr68 = (c(1).^2 + d(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(c(1).^2 - d(1).^2));
expr69 = (c(2).^2 + d(2).^2).^2 + w2.^2.*(w2.^2 + 2.*(c(2).^2 - d(2).^2));
expr70 = 1./2;
expr71 = (-1 + expr61.*expr62.*(expr63.*expr64).^expr65.*expr66.*expr67.*(expr68.*expr69).^expr70).^2;
integrate2 = trapz(w2, expr71);
w3 = [wp:(-wp + ws)./100:ws];
expr72 = -(w3./(wp - ws));
expr73 = ws./(wp - ws);
expr74 = a(1).^2 + b(1).^2;
expr75 = a(2).^2 + b(2).^2;
expr76 = (a(1).^2 + b(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(1).^2 - b(1).^2));
expr77 = (a(2).^2 + b(2).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(2).^2 - b(2).^2));
expr78 = -1./2;
expr79 = (c(1).^2 + d(1).^2).^(-1);
expr80 = (c(2).^2 + d(2).^2).^(-1);
expr81 = (c(1).^2 + d(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(c(1).^2 - d(1).^2));
expr82 = (c(2).^2 + d(2).^2).^2 + w3.^2.*(w3.^2 + 2.*(c(2).^2 - d(2).^2));
expr83 = 1./2;
expr84 = (expr72 + expr73 + expr74.*expr75.*(expr76.*expr77).^expr78.*expr79.*expr80.*(expr81.*expr82).^expr83).^2;
integrate3 = trapz(w3, expr84);
w4 = [0:wmax./100:wmax];
expr85 = angle(1 + (i.*(w4 - b(1)))./a(1));
expr86 = angle(1 + (i.*(w4 + b(1)))./a(1));
expr87 = angle(1 + (i.*(w4 - b(2)))./a(2));
expr88 = angle(1 + (i.*(w4 + b(2)))./a(2));
expr89 = -angle(1 + (i.*(w4 - d(1)))./c(1));
expr90 = -angle(1 + (i.*(w4 + d(1)))./c(1));
expr91 = -angle(1 + (i.*(w4 - d(2)))./c(2));
expr92 = -angle(1 + (i.*(w4 + d(2)))./c(2));
expr93 = wmax.^(-3);
expr94 = 1./2;
expr95 = -2.*wmax.*a(1);
expr96 = angle(1 + (i.*(wmax - b(1)))./a(1)) + angle(1 + (i.*(wmax + b(1)))./a(1));
expr97 = -wmax.^2 - a(1).^2 + b(1).^2;
expr98 = -(a(1).*b(1).*log(1 + (wmax - b(1)).^2./a(1).^2));
expr99 = a(1).*b(1).*log(1 + (wmax + b(1)).^2./a(1).^2);
expr100 = -2.*wmax.*a(2);
expr101 = angle(1 + (i.*(wmax - b(2)))./a(2)) + angle(1 + (i.*(wmax + b(2)))./a(2));
expr102 = -wmax.^2 - a(2).^2 + b(2).^2;
expr103 = -(a(2).*b(2).*log(1 + (wmax - b(2)).^2./a(2).^2));
expr104 = a(2).*b(2).*log(1 + (wmax + b(2)).^2./a(2).^2);
expr105 = 2.*wmax.*c(1);
expr106 = angle(1 + (i.*(wmax - d(1)))./c(1)) + angle(1 + (i.*(wmax + d(1)))./c(1));
expr107 = -wmax.^2 - c(1).^2 + d(1).^2;
expr108 = c(1).*d(1).*log(1 + (wmax - d(1)).^2./c(1).^2);
expr109 = -(c(1).*d(1).*log(1 + (wmax + d(1)).^2./c(1).^2));
expr110 = 2.*wmax.*c(2);
expr111 = angle(1 + (i.*(wmax - d(2)))./c(2)) + angle(1 + (i.*(wmax + d(2)))./c(2));
expr112 = -wmax.^2 - c(2).^2 + d(2).^2;
expr113 = c(2).*d(2).*log(1 + (wmax - d(2)).^2./c(2).^2);
expr114 = -(c(2).*d(2).*log(1 + (wmax + d(2)).^2./c(2).^2));
expr115 = (expr100 - expr101.*expr102 + expr103 + expr104).*expr94 + (expr105 + expr106.*expr107 + expr108 + expr109).*expr94 + (expr110 + expr111.*expr112 + expr113 + expr114).*expr94 + expr94.*(expr95 - expr96.*expr97 + expr98 + expr99);
expr116 = (expr85 + expr86 + expr87 + expr88 + expr89 + expr90 + expr91 + expr92 - 3.*expr115.*expr93.*w4).^2;
integrate4 = trapz(w4, expr116);
expr117 = (integrate2.*Wmp)./wp;
expr118 = (integrate4.*Wph)./wmax;
expr119 = (integrate1.*Wms)./(99.*ws);
expr120 = (integrate3.*Wmt)./(-wp + ws);
expr121 = 1./2;
expr122 = sqrt((sqrt(a(1).^2 + b(1).^2).*sqrt(a(2).^2 + b(2).^2))./(a(1).*a(2)));
expr123 = b(1).^(-1);
expr124 = a(2).^2 + b(2).^2;
expr125 = ((a(1) - a(2)).^2 + (b(1) - b(2)).^2).*((a(1) - a(2)).^2 + (b(1) + b(2)).^2);
expr126 = -1./2;
expr127 = (c(1).^2 + d(1).^2).^(-1);
expr128 = (c(2).^2 + d(2).^2).^(-1);
expr129 = (a(1) - c(1)).^2 + (b(1) - d(1)).^2;
expr130 = (a(1) - c(1)).^2 + (b(1) + d(1)).^2;
expr131 = (a(1) - c(2)).^2 + (b(1) - d(2)).^2;
expr132 = (a(1) - c(2)).^2 + (b(1) + d(2)).^2;
expr133 = b(1);
expr134 = angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2)));
expr135 = angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2)));
expr136 = -angle(1 + (i.*(b(1) - d(1)))./(a(1) - c(1)));
expr137 = -angle(1 + (i.*(b(1) + d(1)))./(a(1) - c(1)));
expr138 = -angle(1 + (i.*(b(1) - d(2)))./(a(1) - c(2)));
expr139 = -angle(1 + (i.*(b(1) + d(2)))./(a(1) - c(2)));
expr140 = a(1);
expr141 = exp(tpeak1.*a(1));
expr142 = cos(tpeak1.*b(1));
expr143 = a(1).^2 + b(1).^2;
expr144 = sin(tpeak1.*b(1));
expr145 = b(2).^(-1);
expr146 = ((-a(1) + a(2)).^2 + (-b(1) + b(2)).^2).*((-a(1) + a(2)).^2 + (b(1) + b(2)).^2);
expr147 = (a(2) - c(1)).^2 + (b(2) - d(1)).^2;
expr148 = (a(2) - c(1)).^2 + (b(2) + d(1)).^2;
expr149 = (a(2) - c(2)).^2 + (b(2) - d(2)).^2;
expr150 = (a(2) - c(2)).^2 + (b(2) + d(2)).^2;
expr151 = b(2);
expr152 = angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2)));
expr153 = angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2)));
expr154 = -angle(1 + (i.*(b(2) - d(1)))./(a(2) - c(1)));
expr155 = -angle(1 + (i.*(b(2) + d(1)))./(a(2) - c(1)));
expr156 = -angle(1 + (i.*(b(2) - d(2)))./(a(2) - c(2)));
expr157 = -angle(1 + (i.*(b(2) + d(2)))./(a(2) - c(2)));
expr158 = a(2);
expr159 = exp(tpeak1.*a(2));
expr160 = cos(tpeak1.*b(2));
expr161 = sin(tpeak1.*b(2));
expr162 = (-0.5 + expr121.*expr122).*WQ;
expr163 = expr125.^expr126;
expr164 = (expr129.*expr130.*expr131.*expr132).^expr121;
expr165 = expr133.*cos(expr134 + expr135 + expr136 + expr137 + expr138 + expr139) + expr140.*sin(expr134 + expr135 + expr136 + expr137 + expr138 + expr139);
expr166 = expr140 - (expr143.*sin(expr134 + expr135 + expr136 + expr137 + expr138 + expr139))./(expr133.*cos(expr134 + expr135 + expr136 + expr137 + expr138 + expr139) + expr140.*sin(expr134 + expr135 + expr136 + expr137 + expr138 + expr139));
expr167 = expr146.^expr126;
expr168 = (expr147.*expr148.*expr149.*expr150).^expr121;
expr169 = expr151.*cos(expr152 + expr153 + expr154 + expr155 + expr156 + expr157) + expr158.*sin(expr152 + expr153 + expr154 + expr155 + expr156 + expr157);
expr170 = expr158 - (expr124.*sin(expr152 + expr153 + expr154 + expr155 + expr156 + expr157))./(expr151.*cos(expr152 + expr153 + expr154 + expr155 + expr156 + expr157) + expr158.*sin(expr152 + expr153 + expr154 + expr155 + expr156 + expr157));
expr171 = expr123.*expr124.*expr127.*expr128.*expr163.*expr164.*expr165.*(1 - expr141.*(expr142 - expr123.*expr144.*expr166));
expr172 = expr127.*expr128.*expr143.*expr145.*expr167.*expr168.*expr169.*(1 - expr159.*(expr160 - expr145.*expr161.*expr170));
expr173 = expr117 + expr118 + expr119 + expr120 + expr162 + 100.*(-1 + expr171 + expr172).^2.*WO;
f = expr173;

%% Debugging code
global numtimes weights;
weights = weights + [ (integrate1.*Wms)./(99.*ws) (integrate2.*Wmp)./wp (integrate3.*Wmt)./(-wp + ws) (integrate4.*Wph)./wmax ] / f;
numtimes = numtimes + 1;

end
