%% Matlab script to run the optimization
%% Code Generated by Mathematica packages written by Brian L. Evans
%% Copyright 1993 by the Regents of the University of California

%% This program uses the following global variables:
global dp ds maxO wmax Wmp Wms Wmt WO wp Wph WQ ws tpeak1;

%% The following constants have been given default values:
Wmp = 0;             %% weight on mag. response in passband
Wmt = 0;             %% weight on mag. response in transition band
Wms = 1;             %% weight on mag. response in stopband
Wph = 1;           %% weight on deviation from linear phase
WQ = .5;              %% weight on quality factor cost
WO = 1;              %% weight on percent overshoot cost
wp = 30;             %% end of passband frequency
ws = 50;             %% start of stopband frequency
wmax = wp;           %% max. frequency for filter to exhibit linear phase
maxO = 20;           %% max. percent overshoot of the step response
dp =  .2;           %% allowable mag. error in the passband
ds =  .3;           %% allowable mag. error in the stopband

%% The program uses one global variable that is updated at each iteration:
%%	tpeak1 the time at which the peak in the step response occurs

%% Debugging code
global numtimes weights;
weights = [0 0 0 0];
numtimes = 0;

%load x0;
%clear pi;

x0=[-1.6821e+01  -7.3348e+00  -1.7224e+00  -1.2881e+01  -2.7291e+01  -3.1139e+01 2.1955e-16   7.1054e-15  -1.0658e-14  -3.7082e+01  -1.1007e+02  -4.5514e+01];

tpeak1 = fmin( 'stepresp', 0,max([-(pi./x0(4)),-(pi./x0(5)),-(pi./x0(6))]), [], x0(1:3), x0(4:6),x0(7:9),x0(10:12), -1 );
if ( stepresp(tpeak1, x0(1:3), x0(4:6), x0(7:9),x0(10:12) , 1) - 1 ) > maxO./100
  fprintf(1, '  overshoot for the initial guess is higher than minimum.\n');
end

%% Do 10 iterations at a time and quit when the first three
%% digits of the value of the cost function remain constant

options = foptions;
options(1) = 2;
options(9) = 1;
options(14) = 50;
errvec = [-100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps, -100.*eps];
[root, options] = constr('filcost3', x0, options, [], errvec, 'costder3');
lastcost = filcost3(x0);
while ( abs( (lastcost - options(8) ) / lastcost) > 1e-3 ),
  lastcost = options(8);
  [root, options] = constr('filcost3', root, options, [], errvec, 'costder3');
end;
disp('The conjugate zero pairs are located at:');
zeroloc = root(7:9) +i*root(10:12);
disp(zeroloc);
disp('The conjugate pole pairs are located at:');
poleloc = root(1:3) +i*root(4:6);
disp(poleloc);

%% Normalized weight vector
weights / numtimes

