(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    119445,       4365]*)
(*NotebookOutlinePosition[    120250,       4393]*)
(*  CellTagsIndexPosition[    120206,       4389]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["All-Pole Filter Optimization", "Title"],

Cell["\<\
Niranjan Damera-Venkata and
Brian L. Evans\
\>", "Subtitle"],

Cell["\<\
Embedded Signal Processing Laboratory
Department of Electrical and Computer Engineering
The University of Texas at Austin
Austin, Texas 78712-1084\
\>", "Subsubtitle"],

Cell["http://anchovy.ece.utexas.edu", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell["Add the filter optimization packages to the path.", "Text"],

Cell[BoxData[
    \(\(AppendTo[$Path, \ "\<../Packages\>"]; \)\)], "Input",
  InitializationCell->True],

Cell["Initialize the filter optimization packages.", "Text"],

Cell[BoxData[
    \(\(Needs[\ "\<FilterOptimization`Master`\>"\ ]; \)\)], "Input",
  InitializationCell->True],

Cell["\<\
Clear several global variables.  You can ignore the two spell error \
warnings.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Clear[\ Wmp, \ Wmt, \ Wms, \ Wph, \ WQ, \ WO, \ a, \ b, \ c, \ d, \ 
      wp, \ ws, \ wmax, \ maxO, \ dp, \ ds\ ]; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(wmax\)\" is similar to \
existing symbol \"\!\(max\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(maxO\)\" is similar to \
existing symbol \"\!\(max\)\"."\)], "Message"]
}, Closed]],

Cell[BoxData[
    \(\(Begin["\<FilterOptimization`Generator`Private`\>"]; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Fourth-Order All-Pole Filter Optimization", "Section"],

Cell["\<\
The subscript 1 denotes the original analog Butterworth filter \
whose behavior is plotted in dashed lines.  The subscript2 denotes the \
all-pole filter simultaneously optimized for step response and linear phase \
over the passed, whose behavior is plotted in solid lines.  This example \
comexs from the following paper:\
\>", "Text"],

Cell[TextData[{
  "B. L. Evans, D. R. Firth, K. D. White, and E. A. Lee, ``Automatic \
Generation of Programs That Jointly Optimize Characteristics of Analog Filter \
Designs'', ",
  StyleBox["Proc. of European Conference on Circuit Theory and Design",
    FontSlant->"Italic"],
  ", Istanbul, Turkey, August 27-31, 1995, pp. 1047-1050. \
http://ptolemy.eecs.berkeley.edu/papers/filter_design_ecctd95.ps.Z."
}], "Text"],

Cell[CellGroupData[{

Cell["Defining the order of the problem and pole locations", "Subsection"],

Cell["\<\
The variable n represents the number of pole pairs, and m denotes \
the number of zero pairs in the analog filter.\
\>", "Text"],

Cell[BoxData[
    \(n\  = \ 2; \nm\  = \ 0; \)], "Input",
  InitializationCell->True],

Cell["The pole pairs are r[1] +/- I i[1] and r[2] +/- I i[2].", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sub1
       = {r[1] -> \(-8.4149\), i[1] -> \ \(-20.3153\), r[2] -> \(-20.3153\), 
        i[2] -> \(-8.4149\)}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(r[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["8.41489999999999938`",
              StyleBoxAutoDelete->True,
              PrintPrecision->5]}]}], ",", 
        RowBox[{\(i[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["20.3153000000000005`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}], ",", 
        RowBox[{\(r[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["20.3153000000000005`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}], ",", 
        RowBox[{\(i[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["8.41489999999999938`",
              StyleBoxAutoDelete->True,
              PrintPrecision->5]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sub2
       = {r[1] -> \(-19.5623\), i[1] -> \(-.6255\), r[2] -> \(-7.7918\), 
        i[2] -> \(-22.8984\)}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(r[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["19.5623000000000004`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}], ",", 
        RowBox[{\(i[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["0.6254999999999999`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}]}], ",", 
        RowBox[{\(r[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["7.79180000000000028`",
              StyleBoxAutoDelete->True,
              PrintPrecision->5]}]}], ",", 
        RowBox[{\(i[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["22.8983999999999987`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude response", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(magnitudePlot1\  = \n
      Plot[\((20\ Log[10, magnitude[r\ , i\ , c\ , d\ , n\ , m\ , \ w]]\  /. 
            \ sub1)\), {w, 0, 100}, \ PlotStyle -> {Dashing[{.02, .02}]}, \ 
        PlotRange -> All]\ ; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.603319 0.0111852 [
[.21429 .59082 -6 -9 ]
[.21429 .59082 6 0 ]
[.40476 .59082 -6 -9 ]
[.40476 .59082 6 0 ]
[.59524 .59082 -6 -9 ]
[.59524 .59082 6 0 ]
[.78571 .59082 -6 -9 ]
[.78571 .59082 6 0 ]
[.97619 .59082 -9 -9 ]
[.97619 .59082 9 0 ]
[.01131 .04406 -18 -4.5 ]
[.01131 .04406 0 4.5 ]
[.01131 .15591 -18 -4.5 ]
[.01131 .15591 0 4.5 ]
[.01131 .26776 -18 -4.5 ]
[.01131 .26776 0 4.5 ]
[.01131 .37961 -18 -4.5 ]
[.01131 .37961 0 4.5 ]
[.01131 .49147 -18 -4.5 ]
[.01131 .49147 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(20)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(40)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(60)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(80)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(100)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .04406 m
.03006 .04406 L
s
[(-50)] .01131 .04406 1 0 Mshowa
.02381 .15591 m
.03006 .15591 L
s
[(-40)] .01131 .15591 1 0 Mshowa
.02381 .26776 m
.03006 .26776 L
s
[(-30)] .01131 .26776 1 0 Mshowa
.02381 .37961 m
.03006 .37961 L
s
[(-20)] .01131 .37961 1 0 Mshowa
.02381 .49147 m
.03006 .49147 L
s
[(-10)] .01131 .49147 1 0 Mshowa
.125 Mabswid
.02381 .06643 m
.02756 .06643 L
s
.02381 .0888 m
.02756 .0888 L
s
.02381 .11117 m
.02756 .11117 L
s
.02381 .13354 m
.02756 .13354 L
s
.02381 .17828 m
.02756 .17828 L
s
.02381 .20065 m
.02756 .20065 L
s
.02381 .22302 m
.02756 .22302 L
s
.02381 .24539 m
.02756 .24539 L
s
.02381 .29013 m
.02756 .29013 L
s
.02381 .3125 m
.02756 .3125 L
s
.02381 .33487 m
.02756 .33487 L
s
.02381 .35724 m
.02756 .35724 L
s
.02381 .40199 m
.02756 .40199 L
s
.02381 .42436 m
.02756 .42436 L
s
.02381 .44673 m
.02756 .44673 L
s
.02381 .4691 m
.02756 .4691 L
s
.02381 .51384 m
.02756 .51384 L
s
.02381 .53621 m
.02756 .53621 L
s
.02381 .55858 m
.02756 .55858 L
s
.02381 .58095 m
.02756 .58095 L
s
.02381 .02169 m
.02756 .02169 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.02954 .60332 L
.03053 .60332 L
.03163 .60332 L
.03279 .60332 L
.03395 .60332 L
.0352 .60332 L
.03638 .60332 L
.03746 .60332 L
.03873 .60332 L
.03944 .60332 L
.04011 .60332 L
.04132 .60332 L
.04262 .60332 L
.04327 .60332 L
.04396 .60332 L
.04519 .60332 L
.04588 .60332 L
.04652 .60332 L
.04726 .60332 L
.04797 .60332 L
.04925 .60332 L
.05041 .60332 L
.05166 .60332 L
.05302 .60332 L
.05414 .60332 L
.05539 .60332 L
.05669 .60332 L
.05791 .60332 L
.06009 .60332 L
.06132 .60332 L
.06244 .60332 L
.0649 .60332 L
.06627 .60332 L
.06752 .60332 L
.06869 .60332 L
.06995 .60332 L
.07225 .60332 L
.07354 .60332 L
.07496 .60332 L
.07634 .60332 L
.07783 .60332 L
.08048 .60332 L
.08297 .60332 L
.08574 .60332 L
.08876 .60331 L
Mistroke
.09162 .60331 L
.09426 .60331 L
.09688 .60331 L
.09926 .60331 L
.102 .6033 L
.10458 .6033 L
.10925 .60328 L
.1119 .60327 L
.11437 .60326 L
.11936 .60323 L
.12215 .6032 L
.1247 .60318 L
.12925 .60312 L
.1342 .60303 L
.13887 .60292 L
.14318 .60278 L
.14783 .60259 L
.15284 .60232 L
.15756 .60199 L
.16188 .60161 L
.17193 .60037 L
.17698 .59949 L
.1825 .59831 L
.1928 .59529 L
.20215 .59146 L
.21294 .58552 L
.22311 .57832 L
.24317 .55981 L
.26163 .5389 L
.30109 .48935 L
.33903 .4426 L
.37942 .39685 L
.4183 .35693 L
.45962 .31838 L
.49944 .28447 L
.53774 .25441 L
.57848 .22477 L
.61772 .19822 L
.65544 .1743 L
.69561 .15034 L
.73426 .1286 L
.77537 .10674 L
.81496 .08679 L
.85304 .06853 L
.89357 .04998 L
.93258 .03293 L
.97405 .01559 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000?l0
8@0001D000<10000o`0900005@000`40003o00T0000E00030@000?l02@0001D000<10000o`090000
5@000`40003o00T0000E00030@000?l02@0001D00P7i00813P0001D000<10000mP020A00000E0003
0@000?@00P4B00005@000`40003o00T0000700<110020@D000<10000kP020AP0000:00040@000@80
00<100000P000`40003/00816P0000X000@100010P000`40000200<1jP020A`000000`010@020@80
0`4300040@000@@000<10000o`0900001`000`40000300040@000@@000<10000i@000`40000P0000
1`000`40000300040@000@@000<10000h`020B<0000700@10`020@D000<10000h@020BD0000E0003
0@000>0000<100009@0001D00P7o00X0000E00030@000=X00P4/00005@000`40003H0081;P0001D0
00<10000eP020C00000E00030@000?l02@0001D000<10000dP000`40000c00005@020M400P4f0000
5@000`40003>0081>00001D000<10000c@000`40000h00005@000`40003o00T0000E00030@000<P0
00<10000?@0001D000<10000aP020D00000E0081a@020D80000E00030@000<<000<10000@P0001D0
00<10000o`0900005@000`40002m0081B@0001D000<10000_0000`40001900005@000`40002k0003
0@0004X0000E0081^`000`40001;00005@000`40003o00T0000E00030@000?l02@0001D000<10000
]0020E80000900030@0000800P4500030@000;400`5D00002@001@400001008000<100000P000`40
002`00030@0005D0000600D10P001040004400<1o`09000000<00@400P401@01000100<000@10001
10000`40003o00T0000700030@0100<000@1000110000`40002/00030@0005T0000800810`001040
004400030@000:X00P5L00002@000`40000200811@000`40002X0081GP0001D000<10000Y`000`40
001N00005@020Ol02P0001D000<10000o`0900005@000`40002R00030@0006<0000E00030@000:00
0P5V00005@000`40002O00030@0006H0000E00030@0009h000<10000I`0001D00P7o00X0000E0003
0@000?l02@0001D000<10000V@000`40001/00005@000`40002G0081K`0001D000<10000UP000`40
001_00005@000`40002E00030@000700000E0081o`0:00005@000`40003o00T0000E00030@000940
00<10000M00001D000<10000S`020GL0000E00030@0008d00P5i00005@000`40002<00030@0007T0
000E0081o`0:00005@000`40003o00T0000E00030@0008L00P5o00005@000`40002600030@0007l0
000E00030@0008D000<10000P00000P00P4400811@000`40002400030@000840000700040@000@80
00@1000110030Ol02@0000X000@100010P000`40000200030@000?l02@000003004100810`020@<0
00@1000110000`40003o00T0000:00040@000@8000<100000P000`40001n0081R00000L000@10001
0P001040004400030@0007d000<10000R00000P00P4400811@000`40001l00030@0008T0000E0081
O0000`40002:00005@000`40003o00T0000E00030@000?l02@0001D000<10000o`0900005@000`40
001g00030@0008h0000E00030@0007D00P6A00005@020GD000<10000T@0001D000<10000L`000`40
002B00005@000`40003o00T0000E00030@000?l02@0001D000<10000o`0900005@000`40001_0003
0@0009H0000E0081KP020IT0000E00030@0006`000<10000V@0001D000<10000J`000`40002J0000
5@000`40003o00T0000E00030@000?l02@0001D000<10000o`0900005@020FP000<10000WP0001D0
00<10000IP000`40002O00005@000`40001U00030@000:00000E00030@0006@000<10000X@0001D0
00<10000H`000`40002R00001`040@<00P4500030@000?l02@0000L000<100000`001040004400<1
o`09000020000`40000200040@000@@000<10000o`09000000<00@400P4400050@0000400P000`40
000200030@00060000<10000Y@0000X000@100010P000`40000200030@0005l000<10000YP0000L0
00@100010P001040004400030@0005h000<10000Y`0000P00P4400811@000`40001M00030@000:P0
000E0081G@000`40002Y00005@000`40003o00T0000E00030@000?l02@0001D000<10000o`090000
5@000`40001H00030@000:d0000E00030@0005L000<10000[P0001D00P5H00030@000:h0000E0003
0@0005H000<10000[`0001D000<10000E@000`40002`00005@000`40003o00T0000E00030@000?l0
2@0001D000<10000o`0900005@020E8000<10000]00001D000<10000D0000`40002e00005@000`40
001@00030@000;D0000E00030@0004l000<10000]P0001D000<10000CP000`40002g00005@000`40
003o00T0000E0081o`0:00005@000`40003o00T0000E00030@0004X000<10000^`0001D000<10000
BP000`40002k00005@000`40001900030@000;`0000700@10`020@D000<10000B@000`40002l0000
2@001@400001008000<100000P030DL00P6o00002@001@400001008000<100000P000`40003o00T0
00000`010@020@@000D100000@0200030@00008000<10000o`0900002@001@400001008000<10000
0P000`40003o00T0000700<10`001040004400030@000?l02@0000T000<100000P020@D000<10000
A0000`40003100005@020D@000<10000`P0001D000<10000@P000`40003300005@000`4000110003
0@000<@0000E00030@00040000<10000a@0001D000<10000o`0900005@000`40003o00T0000E0081
o`0:00005@000`40000m00030@000<P0000E00030@0003`000<10000b@0001D000<10000>`000`40
003:00005@000`40000j00030@000</0000E00030@0003T000<10000c00001D00P7o00X0000E0003
0@000?l02@0001D000<10000o`0900005@000`40000f00030@000<l0000E00030@0002/010430081
00<00@00:P000`4000020081:`020@@00P4[008110020BP01043008110020@<0000E00030@0002/0
00<100000`001040004/00050@0000400P000`40000W00040@000@8000@10001:@00104000420004
0@000BT000D100000@0200040@000@800@410040000E0081;@000`40000200@1:@050@8000@10001
:@001040004200040@000BT000@100010P001040004Y00050@0000400P001040004200410@010000
5@000`40000]00050@0000400P000`40000W00040@000@<000@10001:@030@<000@10001:P020@<0
00@10001:@001@400001008000@100010P010@400@0001D000<10000;P001040004200030@0002P0
00<100400`001040004Y00030@0000<000@10001:@001040004200040@000BT000D100000@020004
0@000@800@410040000E00030@0002/0104200040@000B/00P4300040@000BT000<100000`001040
004Y00040@000@8000@100019`030@<000@100010P001040004200005@000`40000Y00D110020Bd0
00<100000P020B/00`430081:`020@@00P4Z00030@0000800P4400810`0001D000<10000:0000`40
003M00003P3o0A010`0001D000<100002P000`40000:00030@0000T000<100002P000`40000:0003
0@0000X000<100002P000`40000:00030@0000T000<100002P000`40000:00030@0000X000<10000
2P000`40000:00030@0000T000<100002P000`40000:00030@0000X000<100002P000`40000:0003
0@0000L0000E00030@00030000<10000<@000`40000`00030@00030000<10000<@000`4000070000
5@000`40003o00T0000E00030@000?l02@000?l08@000?l08@000?l08@000?l08@000?l08@000001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.32696, -55.6648, 0.389667,
   0.331788}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(magnitudePlot2\  = \n\t
      Plot[\((20\ Log[10, magnitude[r\ , i\ , c\ , d\ , n\ , m\ , \ w]\ ] /. 
            \ sub2)\), {w, 0, 100}, PlotRange -> All]\ ; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.603319 0.0111246 [
[.21429 .59082 -6 -9 ]
[.21429 .59082 6 0 ]
[.40476 .59082 -6 -9 ]
[.40476 .59082 6 0 ]
[.59524 .59082 -6 -9 ]
[.59524 .59082 6 0 ]
[.78571 .59082 -6 -9 ]
[.78571 .59082 6 0 ]
[.97619 .59082 -9 -9 ]
[.97619 .59082 9 0 ]
[.01131 .04709 -18 -4.5 ]
[.01131 .04709 0 4.5 ]
[.01131 .15833 -18 -4.5 ]
[.01131 .15833 0 4.5 ]
[.01131 .26958 -18 -4.5 ]
[.01131 .26958 0 4.5 ]
[.01131 .38083 -18 -4.5 ]
[.01131 .38083 0 4.5 ]
[.01131 .49207 -18 -4.5 ]
[.01131 .49207 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(20)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(40)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(60)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(80)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(100)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .04709 m
.03006 .04709 L
s
[(-50)] .01131 .04709 1 0 Mshowa
.02381 .15833 m
.03006 .15833 L
s
[(-40)] .01131 .15833 1 0 Mshowa
.02381 .26958 m
.03006 .26958 L
s
[(-30)] .01131 .26958 1 0 Mshowa
.02381 .38083 m
.03006 .38083 L
s
[(-20)] .01131 .38083 1 0 Mshowa
.02381 .49207 m
.03006 .49207 L
s
[(-10)] .01131 .49207 1 0 Mshowa
.125 Mabswid
.02381 .06934 m
.02756 .06934 L
s
.02381 .09159 m
.02756 .09159 L
s
.02381 .11384 m
.02756 .11384 L
s
.02381 .13609 m
.02756 .13609 L
s
.02381 .18058 m
.02756 .18058 L
s
.02381 .20283 m
.02756 .20283 L
s
.02381 .22508 m
.02756 .22508 L
s
.02381 .24733 m
.02756 .24733 L
s
.02381 .29183 m
.02756 .29183 L
s
.02381 .31408 m
.02756 .31408 L
s
.02381 .33633 m
.02756 .33633 L
s
.02381 .35858 m
.02756 .35858 L
s
.02381 .40308 m
.02756 .40308 L
s
.02381 .42533 m
.02756 .42533 L
s
.02381 .44757 m
.02756 .44757 L
s
.02381 .46982 m
.02756 .46982 L
s
.02381 .51432 m
.02756 .51432 L
s
.02381 .53657 m
.02756 .53657 L
s
.02381 .55882 m
.02756 .55882 L
s
.02381 .58107 m
.02756 .58107 L
s
.02381 .02484 m
.02756 .02484 L
s
.02381 .00259 m
.02756 .00259 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60331 L
.02729 .6033 L
.02846 .60329 L
.03053 .60326 L
.03279 .60321 L
.03527 .60314 L
.0379 .60306 L
.04262 .60285 L
.05205 .60228 L
.06244 .60143 L
.0842 .59901 L
.10458 .59629 L
.14335 .5912 L
.16306 .58902 L
.17347 .5879 L
.18458 .5866 L
.19538 .58501 L
.20517 .58306 L
.21501 .5803 L
.22428 .57672 L
.23405 .57163 L
.24436 .56458 L
.26284 .54768 L
.30081 .50156 L
.34123 .44927 L
.38014 .40278 L
.4215 .35844 L
.46135 .32011 L
.49968 .2866 L
.54046 .25398 L
.57972 .22505 L
.61748 .19919 L
.65768 .17347 L
.69637 .15027 L
.73751 .12706 L
.77713 .10597 L
.81524 .08673 L
.8558 .06727 L
.89484 .04942 L
.93634 .03132 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000?l0
8@0001D00P7o00X0000E00030@000?l02@0001D000<10000o`0900005@000`40003o00T0000E0003
0@000?d00P4900005@000`40003j00<12`0001D00P7i00813P0001D000<10000m@030A00000E0003
0@000?800`4C00005@000`40003`00815P0001D000<10000kP020AP0000700<110020@D000<10000
k0020AX0000:00040@000@8000<100000P030NX00P4L00002P001040004200030@00008000<10000
i`030Ah000000`010@020@800`4300040@000@@000<10000i@020B40000700030@0000<000@10001
10000`40003S00818`0000L000<100000`001040004400030@000>400P4U00001`040@<00P450003
0@000=l00P4W00005@020Md00`4Y00005@000`40003J0081;00001D000<10000f0020Bh0000E0003
0@000=H00P4`00005@000`40003D0081<P0001D000<10000d@030C@0000E0081d0020CL0000E0003
0@000<d00P4i00005@000`40003;0081>`0001D000<10000b@020Cd0000E00030@000<P000<10000
?@0001D000<10000aP020D00000E0081a@020D80000E00030@000<800P5400005@000`4000300081
AP0001D000<10000_P020DP0000E00030@000;d000<10000B00001D000<10000^`020D/0000E0081
^P020Dd0000E00030@000;L00P5?00005@000`40002e0081D@0001D000<10000/`020E<0000E0003
0@000;8000<10000D`0000T000<100000P020@D000<10000/0020EH0000900050@0000400P000`40
000200<1[`000`40001F00001P050@8000@1000110000`40002]0081F@0000030041008100D00@00
0@0300040@000@@000<10000[0000`40001I00001`000`400@0300040@000@@000<10000Z`000`40
001J000020020@<000@1000110000`40002Y0081G@0000T000<100000P020@D000<10000Z0000`40
001M00005@020JL00P5P00005@000`40002T0081HP0001D000<10000XP020F@0000E00030@000:00
0P5V00005@000`40002N0081J00001D000<10000W@000`40001X00005@020I`00P5[00005@000`40
002J00030@0006/0000E00030@0009P00P5^00005@000`40002G00030@0006h0000E00030@0009H0
00<10000K`0001D000<10000U0020G80000E0081U0000`40001b00005@000`40002A0081M@0001D0
00<10000T0000`40001e00005@000`40002?00030@0007H0000E00030@0008d00P5i00005@000`40
002<00030@0007T0000E0081S0000`40001j00005@000`4000290081O@0001D000<10000R0000`40
001m00005@000`40002700030@0007h0000E00030@0008D00P61000020020@@00P4500030@0008@0
00<10000P@0000L000@100010P001040004400<1P`000`40002200002P001040004200030@000080
00<10000PP000`400023000000<00@400P4300810`001040004400030@00084000<10000Q00000X0
00@100010P000`40000200030@0007l00P6700001`001040004200040@000@@000<10000OP000`40
0027000020020@@00P4500030@0007d000<10000R00001D00P5m00030@0008T0000E00030@0007/0
00<10000RP0001D000<10000NP000`40002;00005@000`40001h0081SP0001D000<10000M`000`40
002>00005@000`40001f00030@0008l0000E0081MP000`40002@00005@000`40001d00030@000940
000E00030@0007<000<10000TP0001D000<10000LP000`40002C00005@000`40001a00030@0009@0
000E00030@00070000<10000U@0001D00P5`00030@0009H0000E00030@0006d00P6I00005@000`40
001/00030@0009T0000E00030@0006/000<10000VP0001D000<10000JP000`40002K00005@000`40
001Y00030@0009`0000E0081J@000`40002M00005@000`40001W00030@0009h0000E00030@0006H0
00<10000W`0001D000<10000I@000`40002P00005@000`40001T00030@000:40000700@10`020@D0
00<10000H`000`40002R00001`000`40000300040@000@@00`5S00030@000:80000800030@000080
00@1000110000`40001R00030@000:<000000`010@020@@000D100000@0200030@00008000<10000
H@000`40002T00002P001040004200030@00008000<10000H0000`40002U00001`00104000420004
0@000@@000<10000G`000`40002V000020020@@00P4500030@0005h000<10000Y`0001D00P5N0003
0@000:P0000E00030@0005`000<10000Z@0001D000<10000F`000`40002Z00005@000`40001J0003
0@000:/0000E00030@0005X000<10000Z`0001D000<10000F@000`40002/00005@020ET000<10000
[@0001D000<10000E`000`40002^00005@000`40001F00030@000:l0000E00030@0005D000<10000
/00001D000<10000E@000`40002`00005@000`40001D00030@000;40000E0081E0000`40002b0000
5@000`40001B00030@000;<0000E00030@00054000<10000]00001D000<10000D@000`40002d0000
5@000`40001@00030@000;D0000E00030@0004l000<10000]P0001D00P5?00030@000;L0000E0003
0@0004h000<10000]`0001D000<10000C@000`40002h00005@000`40001<00030@000;T0000E0003
0@0004`000<10000^@0000L0104300811@000`40001;00030@000;X0000900050@0000400P000`40
000200<1BP000`40002k00002@001@400001008000<100000P000`40001900030@000;`000000`01
0@020@@000D100000@0200030@00008000<10000B@000`40002l00002@001@400001008000<10000
0P000`40001800030@000;d0000700<10`001040004400030@0004L000<10000_P0000T000<10000
0P020@D000<10000AP000`40002o00005@020DH000<10000`00001D000<10000A0000`4000310000
5@000`40001300030@000<80000E00030@0004<000<10000`P0001D000<10000@P000`4000330000
5@000`40001100030@000<@0000E0081@@000`40003500005@000`40000o00030@000<H0000E0003
0@0003h000<10000a`0001D000<10000?@000`40003800005@000`40000l00030@000<T0000E0003
0@0003/000<10000bP0001D00P4k00030@000</0000E00030@0003T000<10000c00001D000<10000
>0000`40003=00005@000`40000g00030@000<h0000E00030@0002/01043008100<00@40:P000`40
00020081:`020@@00P4[008110020BP01043008110020@<0000E00030@0002/000<100000`040B`0
00D100000@0200030@0002L000@100010P001040004Y00040@000@8000@10001:@001@4000010080
00@100010P010@400@0001D00P4]00030@0000<10P000`40000W00D10P001040004Y00040@000@80
00@10001:@001040004200040@000BT000D100000@0200040@000@800@410040000E00030@0002X0
1@4200040@000BT000@100010`001040004Y00<10`001040004Z00810`001040004Y00050@000040
0P001040004200410@0100005@000`40000P00X110001040004200030@0002P000<100400`001040
004Y00030@0000<000@10001:@001040004200040@000BT000D100000@0200040@000@800@410040
000E00030@0001P0204;00040@000@8000@10001:`020@<000@10001:@000`40000300040@000BT0
00@100010P001040004W00<10`001040004200040@000@80000E00030@000100204D008110020Bd0
00<100000P020B/00`430081:`020@@00P4Z00030@0000800P4400810`0001D000<100002P060OP0
000>0?l1404300005@000`40000:00030@0000X000<100002@000`40000:00030@0000X000<10000
2P000`40000:00030@0000X000<100002@000`40000:00030@0000X000<100002P000`40000:0003
0@0000X000<100002@000`40000:00030@0000X000<100002P000`40000:00030@0000X000<10000
1`0001D000<10000<0000`40000a00030@00030000<10000<0000`40000a00030@0000L0000E0003
0@000?l02@0001D000<10000o`090000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.32696, -55.968, 0.389667, 
  0.333595}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(magnitudeResponses\  = \ 
      Show[magnitudePlot1, \ magnitudePlot2, 
        AxesLabel -> {"\<\[Omega]\>", "\<\>"}]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.603319 0.0111246 [
[.21429 .59082 -6 -9 ]
[.21429 .59082 6 0 ]
[.40476 .59082 -6 -9 ]
[.40476 .59082 6 0 ]
[.59524 .59082 -6 -9 ]
[.59524 .59082 6 0 ]
[.78571 .59082 -6 -9 ]
[.78571 .59082 6 0 ]
[.97619 .59082 -9 -9 ]
[.97619 .59082 9 0 ]
[1.025 .60332 0 -7.5 ]
[1.025 .60332 10 7.5 ]
[.01131 .04709 -18 -4.5 ]
[.01131 .04709 0 4.5 ]
[.01131 .15833 -18 -4.5 ]
[.01131 .15833 0 4.5 ]
[.01131 .26958 -18 -4.5 ]
[.01131 .26958 0 4.5 ]
[.01131 .38083 -18 -4.5 ]
[.01131 .38083 0 4.5 ]
[.01131 .49207 -18 -4.5 ]
[.01131 .49207 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(20)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(40)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(60)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(80)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(100)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
69.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.02381 .04709 m
.03006 .04709 L
s
[(-50)] .01131 .04709 1 0 Mshowa
.02381 .15833 m
.03006 .15833 L
s
[(-40)] .01131 .15833 1 0 Mshowa
.02381 .26958 m
.03006 .26958 L
s
[(-30)] .01131 .26958 1 0 Mshowa
.02381 .38083 m
.03006 .38083 L
s
[(-20)] .01131 .38083 1 0 Mshowa
.02381 .49207 m
.03006 .49207 L
s
[(-10)] .01131 .49207 1 0 Mshowa
.125 Mabswid
.02381 .06934 m
.02756 .06934 L
s
.02381 .09159 m
.02756 .09159 L
s
.02381 .11384 m
.02756 .11384 L
s
.02381 .13609 m
.02756 .13609 L
s
.02381 .18058 m
.02756 .18058 L
s
.02381 .20283 m
.02756 .20283 L
s
.02381 .22508 m
.02756 .22508 L
s
.02381 .24733 m
.02756 .24733 L
s
.02381 .29183 m
.02756 .29183 L
s
.02381 .31408 m
.02756 .31408 L
s
.02381 .33633 m
.02756 .33633 L
s
.02381 .35858 m
.02756 .35858 L
s
.02381 .40308 m
.02756 .40308 L
s
.02381 .42533 m
.02756 .42533 L
s
.02381 .44757 m
.02756 .44757 L
s
.02381 .46982 m
.02756 .46982 L
s
.02381 .51432 m
.02756 .51432 L
s
.02381 .53657 m
.02756 .53657 L
s
.02381 .55882 m
.02756 .55882 L
s
.02381 .58107 m
.02756 .58107 L
s
.02381 .02484 m
.02756 .02484 L
s
.02381 .00259 m
.02756 .00259 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.02954 .60332 L
.03053 .60332 L
.03163 .60332 L
.03279 .60332 L
.03395 .60332 L
.0352 .60332 L
.03638 .60332 L
.03746 .60332 L
.03873 .60332 L
.03944 .60332 L
.04011 .60332 L
.04132 .60332 L
.04262 .60332 L
.04327 .60332 L
.04396 .60332 L
.04519 .60332 L
.04588 .60332 L
.04652 .60332 L
.04726 .60332 L
.04797 .60332 L
.04925 .60332 L
.05041 .60332 L
.05166 .60332 L
.05302 .60332 L
.05414 .60332 L
.05539 .60332 L
.05669 .60332 L
.05791 .60332 L
.06009 .60332 L
.06132 .60332 L
.06244 .60332 L
.0649 .60332 L
.06627 .60332 L
.06752 .60332 L
.06869 .60332 L
.06995 .60332 L
.07225 .60332 L
.07354 .60332 L
.07496 .60332 L
.07634 .60332 L
.07783 .60332 L
.08048 .60332 L
.08297 .60332 L
.08574 .60332 L
.08876 .60331 L
Mistroke
.09162 .60331 L
.09426 .60331 L
.09688 .60331 L
.09926 .60331 L
.102 .6033 L
.10458 .6033 L
.10925 .60328 L
.1119 .60327 L
.11437 .60326 L
.11936 .60323 L
.12215 .6032 L
.1247 .60318 L
.12925 .60312 L
.1342 .60303 L
.13887 .60292 L
.14318 .60278 L
.14783 .60259 L
.15284 .60233 L
.15756 .602 L
.16188 .60162 L
.17193 .60038 L
.17698 .59952 L
.1825 .59833 L
.1928 .59533 L
.20215 .59152 L
.21294 .58562 L
.22311 .57846 L
.24317 .56004 L
.26163 .53925 L
.30109 .48997 L
.33903 .44347 L
.37942 .39797 L
.4183 .35826 L
.45962 .31992 L
.49944 .2862 L
.53774 .2563 L
.57848 .22682 L
.61772 .20042 L
.65544 .17662 L
.69561 .15279 L
.73426 .13117 L
.77537 .10943 L
.81496 .08959 L
.85304 .07142 L
.89357 .05298 L
.93258 .03602 L
.97405 .01878 L
.97619 .0179 L
Mfstroke
[ ] 0 setdash
.02381 .60332 m
.02499 .60332 L
.02605 .60331 L
.02729 .6033 L
.02846 .60329 L
.03053 .60326 L
.03279 .60321 L
.03527 .60314 L
.0379 .60306 L
.04262 .60285 L
.05205 .60228 L
.06244 .60143 L
.0842 .59901 L
.10458 .59629 L
.14335 .5912 L
.16306 .58902 L
.17347 .5879 L
.18458 .5866 L
.19538 .58501 L
.20517 .58306 L
.21501 .5803 L
.22428 .57672 L
.23405 .57163 L
.24436 .56458 L
.26284 .54768 L
.30081 .50156 L
.34123 .44927 L
.38014 .40278 L
.4215 .35844 L
.46135 .32011 L
.49968 .2866 L
.54046 .25398 L
.57972 .22505 L
.61748 .19919 L
.65768 .17347 L
.69637 .15027 L
.73751 .12706 L
.77713 .10597 L
.81524 .08673 L
.8558 .06727 L
.89484 .04942 L
.93634 .03132 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000?l0
8@000?l08@000?l08@0001D000<10000o`0900005@020Ol02P0001D000<10000o`0900005@000`40
003o00T0000E00030@000>l00P4G00005@000`40003]00816@0001D000<10000jP030A/0000E0081
j@030Ad0000E00030@000>D0104O00005@000`40003S00818`0001D000<10000h@030B@0000700<1
10020@D000<10000g`030BH0000:00040@000@8000<100000P020Mh00`4X00002P00104000420003
0@00008000<10000fP030B/000000`010@020@800`4300040@000@@000<10000f0020Bh000070003
0@0000<000@1000110000`40003E00@1;`0000L000<100000`001040004400030@000=<00P400`01
000`00001`040@<00P4500030@000=000`4200030@000300000E0081c`020CP0000E00030@000<`0
0P400`010@0g00005@000`40003:008100<00@40>@0001D000<10000b0020@03004103/0000E0003
0@000<H00P5000005@000`40003400@1@00001D00P7300@1@P0001D000<10000`0040D@0000E0003
0@000;h00P5800005@000`40002m00030@0004P0000E00030@000;/0105900005@020KX00`5<0000
5@000`40002h0081CP0001D000<10000]P020E00000E00030@000;@00P5B00005@000`40002c0081
D`0001D000<10000/@020ED0000E0081/0020EL0000E00030@000:h000<10000E`0001D000<10000
Z`030EX0000E00030@000:T00`5L00002@000`40000200811@000`40002X0081GP0000T000D10000
0@0200030@00008000<10000Y`020El0000600D10P00104000440081YP020F4000000`010@020@05
004000400`001040004400030@000:@000<10000H@0000L000<100400`001040004400030@000:80
0P5T000020020@<000@1000110000`40002P0081IP0000T000<100000P020@D000<10000WP020FP0
000E0081WP020FT0000E00030@0009/00P5[00005@000`40002I0081K@0001D000<10000U`030Fh0
000E00030@0009D00`5`00005@000`40002D00030@010740000E0081U0000`40001b00005@000`40
002A0081M@0001D000<10000S`020GL0000E00030@0008h00P5h00005@000`40002=0081N@0001D0
00<10000S0000`40001i00005@020H`000<10000NP0001D000<10000R@020Gd0000E00030@0008L0
0P5o00005@000`4000260081P00001D000<10000Q@000`40002000005@020HD000<10000P@0001D0
00<10000PP020H@0000E00030@00084000<10000Q00001D000<10000O`020HL0000E00030@0007h0
0P68000020020@@00P4500030@0007d000<10000R00000L000@100010P00104000440081O0020H/0
000:00040@000@8000<100000P000`40001j00030@0008/000000`010@020@<00P4300040@000@@0
00<10000N@000`40002<00002P001040004200030@00008000<10000M`020Hl0000700040@000@80
00@1000110000`40001f00030@0008l00008008110020@D000<10000M@020I40000E0081M@020I80
000E00030@0007<000<10000TP0001D000<10000L@020ID0000E00030@0007000P6F00005@000`40
001_0081U`0001D00P5_00030@0009L0000E00030@0006d000<10000V00001D000<10000K0000`40
002I00005@000`40001[00030@0009X0000E00030@0006X000<10000V`0001D000<10000J@000`40
002L00005@020FP00P6O00005@000`40001V0081X00001D000<10000I@020J40000E00030@0006D0
00<10000X00001D000<10000I0000`40002Q00005@000`40001S00030@000:80000E0081HP020JD0
000E00030@0006000P6V00005@000`40001O0081Y`0001D000<10000GP020JP0000700@10`020@D0
00<10000GP000`40002W00001`000`40000300040@000@@000<10000G@000`40002X000020000`40
000200040@000@@00P5N00030@000:P000000`010@020@@000D100000@0200030@00008000<10000
FP000`400@2[00002P001040004200030@00008000<10000F@000`400@2/00001`00104000420004
0@000@@000<10000F@020Jd00008008110020@D000<10000F0020Jh0000E0081F0020Jl0000E0003
0@0005L000<10000[P0001D000<10000EP000`40002_00005@000`40001D00030@010;40000E0003
0@0005<000<10040/P0001D000<10000DP000`400@2c00005@020E8000<10040]00001D000<10000
D0000`400@2e00005@000`40001A00030@000;@0000E00030@00054000<10000]00001D000<10000
D0000`40002e00005@000`40001=00030@010;P0000E0081C@000`400@2i00005@000`40001<0081
^P0001D000<10000B`020K/0000E00030@0004X00P6l00005@000`40001;00030@000;X0000E0081
B`000`40002k00005@000`40001900030@000;`0000E00030@0004H000<10040_`0001D000<10000
A@000`400@3000005@000`4000150081`@0000L0104300811@000`40001400030@010<4000090005
0@0000400P000`4000020081A0000`400@3200002@001@400001008000<100000P000`4000140003
0@000<4000000`010@020@@000D100000@0200030@00008000<10000@`000`40003200002@001@40
0001008000<100000P000`40001200030@000<<0000700<10`001040004400030@00040000<10040
a@0000T000<100000P020@D000<10000?`000`400@3600005@020D000P7700005@000`40000n0081
b00001D000<10000?@000`400@3800005@000`40000n00030@000<L0000E00030@0003d000<10000
b00001D00P4m00030@000<T0000E00030@0003T00P400`01003:00005@000`40000h00040@000L`0
000E00030@0003P000<10040c@0001D000<10000=`000`400@3>00005@000`40000f00<1c`0001D0
0P4g00030@000<l0000E00030@0003D000<10000d00001D000<10000<P030M<0000E00030@0002P0
104300@1:0000`4000020081:@020@@00P4X008110020BD01043008110020A40000E00030@0002P0
00<100000`001040004Y00050@0000400P000`40000U00040@000@8000@100019P00104000420004
0@000BH000D100000@0200040@000@8000<100003P0001D000<10000:@00104000050BH01@420004
0@000BL000@100010P001040004V00040@000@8000@100019P001@400001008000@100010P000`40
000>00005@020B/00`401@010@0102H000@100010`001040004W00<10`001040004W00810`001040
004V00050@0000400P001040004200030@0000h0000E00030@00028020401@010001008000<10000
9@000`400@0300040@000BL000<100000`001040004V00040@000@8000@100019P001@4000010080
00@100010P000`40000>00005@000`40000I00T11P040@8000@10001:0020@<000@100019`000`40
000300040@000BH000@100010P001040004T00<10`001040004200040@000A00000E00030@0001@0
1@4>00@110020BX000<100000P020BT00`430081:0020@@00P4W00030@0000800P4400812@040@@0
000E00030@0000X02P4A0081f0001P4000400@<0000?0?l10@4800060@000@010`0001D000<10000
2@000`40000900030@0000T000<100002@000`40000:00030@0000T000<100002@000`4000090003
0@0000T000<100002@000`40000:00030@0000T000<100002@000`40000900030@0000T000<10000
2@000`40000:00030@0000T000<100002@000`40000900030@0000`000<100000P000`4000010000
5@000`40000]00030@0002h000<10000;P000`40000]00030@0002h000<100003@001@40000100<0
000E00030@000?l02@0001D000<10000o`090000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000
o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.71025, -56.9225, 0.41096, 
  0.351824}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase response", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(phaseResponse1\  = 
      Plot[\((phase[r\ , i\ , c\ , d\ , n\ , m\ , \ w]\  /. \ sub1)\), {w, 0, 
          20}, PlotStyle -> {Dashing[{.02, .02}]}, PlotRange -> All]; \)\)], 
  "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0476191 0.603319 0.21052 [
[.2619 .59082 -3 -9 ]
[.2619 .59082 3 0 ]
[.5 .59082 -6 -9 ]
[.5 .59082 6 0 ]
[.7381 .59082 -6 -9 ]
[.7381 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[.01131 .07702 -24 -4.5 ]
[.01131 .07702 0 4.5 ]
[.01131 .18228 -12 -4.5 ]
[.01131 .18228 0 4.5 ]
[.01131 .28754 -24 -4.5 ]
[.01131 .28754 0 4.5 ]
[.01131 .3928 -12 -4.5 ]
[.01131 .3928 0 4.5 ]
[.01131 .49806 -24 -4.5 ]
[.01131 .49806 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(5)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(10)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(15)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(20)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .07702 m
.03006 .07702 L
s
[(-2.5)] .01131 .07702 1 0 Mshowa
.02381 .18228 m
.03006 .18228 L
s
[(-2)] .01131 .18228 1 0 Mshowa
.02381 .28754 m
.03006 .28754 L
s
[(-1.5)] .01131 .28754 1 0 Mshowa
.02381 .3928 m
.03006 .3928 L
s
[(-1)] .01131 .3928 1 0 Mshowa
.02381 .49806 m
.03006 .49806 L
s
[(-0.5)] .01131 .49806 1 0 Mshowa
.125 Mabswid
.02381 .09807 m
.02756 .09807 L
s
.02381 .11912 m
.02756 .11912 L
s
.02381 .14017 m
.02756 .14017 L
s
.02381 .16123 m
.02756 .16123 L
s
.02381 .20333 m
.02756 .20333 L
s
.02381 .22438 m
.02756 .22438 L
s
.02381 .24543 m
.02756 .24543 L
s
.02381 .26649 m
.02756 .26649 L
s
.02381 .30859 m
.02756 .30859 L
s
.02381 .32964 m
.02756 .32964 L
s
.02381 .35069 m
.02756 .35069 L
s
.02381 .37175 m
.02756 .37175 L
s
.02381 .41385 m
.02756 .41385 L
s
.02381 .4349 m
.02756 .4349 L
s
.02381 .45595 m
.02756 .45595 L
s
.02381 .47701 m
.02756 .47701 L
s
.02381 .51911 m
.02756 .51911 L
s
.02381 .54016 m
.02756 .54016 L
s
.02381 .56121 m
.02756 .56121 L
s
.02381 .58227 m
.02756 .58227 L
s
.02381 .05597 m
.02756 .05597 L
s
.02381 .03491 m
.02756 .03491 L
s
.02381 .01386 m
.02756 .01386 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .60332 m
.06244 .58302 L
.10458 .56085 L
.14415 .53998 L
.18221 .51983 L
.22272 .49829 L
.26171 .47741 L
.30316 .45505 L
.34309 .43329 L
.3815 .41212 L
.42237 .3893 L
.46172 .36697 L
.49955 .34511 L
.53984 .32136 L
.57861 .29795 L
.61984 .27237 L
.65954 .24698 L
.69774 .22178 L
.73838 .19405 L
.77751 .16642 L
.81909 .13606 L
.85916 .10591 L
.89771 .07622 L
.93871 .04416 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000?l0
8@000?l08@0001/000<10000o`0300006`000`40003o00<0000K00030@000?l00`0001/000<10000
o`0300006`020O/000<100001@0001/000<10000o`0300006`000`40003o00<0000K00030@000?H0
00<100002@0001/000<10000m@000`40000:00006`020O@00P4=00006`000`40003b00030@0000d0
000K00030@000?4000<100003P0001/000<10000o`0300006`000`40003o00<0000K00030@000>d0
00<100004P0001/00P7/00815@0001/000<10000jP000`40000E00006`000`40003Y00030@0001H0
000K00030@000?l00`0000L0104300030@0000800`4500030@000?l00`0000L000<1000030000`40
00020081iP000`40000J000020000`40000;00030@00008000<10000i0000`40000K000000<00@40
0P4400030@0000L00`4500030@000><000<10000700000X000<100001P000`40000500030@000>80
00<100007@0000L000@1000120000`40000500030@000>4000<100007P0000P00P4900@110000`40
003o00<0000K0081o`0400006`000`40003L00030@0002<0000K00030@000=/000<10000900001/0
00<10000f@020BL0000K00030@000=P000<100009`0001/000<10000o`0300006`020Ol0100001/0
00<10000e0000`40000[00006`000`40003B0081;P0001/000<10000d@000`40000^00006`000`40
003@00030@0002l0000K0081d@000`40000_00006`000`40003o00<0000K00030@000?l00`0001/0
00<10000b`000`40000d00006`000`4000390081=`0001/000<10000b0000`40000g00006`020LP0
00<10000>00001/000<10000o`0300006`000`40003o00<0000K00030@000<<000<10000?00001<0
104400030@000<400P4o00004`000`4000050081`0020D40000D00030@0000@000<10000_P000`40
001100003@040@@000<100000`000`40003o00<0000F00030@00008000<10000o`0300004`001040
004400030@000;X000<10000A@0001@00P4500030@000;P00P5800006`020KP000<10000B00001/0
00<10000]P000`40001900006`000`40003o00<0000K00030@000?l00`0001/000<10000/@000`40
001>00006`000`40002`00030@0004l0000K0081[`020E80000K00030@000:d000<10000DP0001/0
00<10000o`0300006`000`40003o00<0000K00030@000:P000<10000E`0001/00P6X00030@0005P0
000K00030@000:D00P5K00006`000`40002T00030@0005/0000K00030@000?l00`0001/000<10000
o`0300006`000`40002N0081HP0001/00P6M0081I00001/000<10000V`000`40001T00006`000`40
002K00030@0006@0000K00030@000?l00`0000L0104300030@0000800`4500030@0009H000<10000
J@0000T000<100002P000`4000020081U@020F`0000900030@0000X000<100000P000`40002C0003
0@0006`000000`010@020@@000<100001`030@D000<10000TP000`40001]00002@000`4000070003
0@0000D000<10000o`0300001`030@T000<100001@000`40003o00<0000900030@0000L010440003
0@0008d000<10000LP0001/00P6<0081M@0001/000<10000RP000`40001e00006`000`4000290003
0@0007H0000K00030@000?l00`0001/000<10000Q0000`40001k00006`000`4000220081OP0001/0
0P6200030@0007h0000K00030@00080000<10000O`0001/000<10000o`0300006`000`40003o00<0
000K00030@0007/000<10000Q00001/00P5j0081Q`0001/000<10000M`020HT0000K00030@0007H0
00<10000R@0001/000<10000o`0300006`000`40001a0081S`0001/000<10000K`020I40000K0081
K`000`40002A00006`000`40001]00030@000980000K00030@000?l00`0001/000<10000J0020IP0
000C00@110000`40001W00030@0009P0000E00030@0000<00P5V0081V`0001D000<100000`000`40
001T00030@0009/0000=00@110000`40000300030@000?l00`0001D000<100000`000`40003o00<0
000C00<11@000`40001N0081XP0001D000<100000`000`40001L0081Y00001/00P5L00030@000:@0
000K00030@000?l00`0001/000<10000o`0300006`000`40001E0081Z`0001/000<10000D`020Jd0
000K00030@0005400P6_00006`020Ol0100001/000<10000o`0300006`000`40001<0081]00001/0
00<10000BP020KH0000K00030@0004P00P6h00006`020Ol0100001/000<10000o`0300006`000`40
00120081_P0001/000<10000@0020L00000K00030@0003l000<10000`00001/000<10000o`030000
6`020Ol0100001/000<10000>P000`40003500006`000`40000h0081b00001/000<10000=P020LX0
0008008110000`40000200<11@000`40000e00030@000<X0000700040@000@/000<100000P020Ol0
100000L000@100012`000`40000200030@00034000<10000cP000003004100810P001040004800<1
1@000`40000_0081d@0000L000@1000120000`40000500030@0002d00P7C00001`00104000480003
0@0000D000<10000;0000`40003C000020020@T0104400030@000?l00`0001/00P4X00030@000=P0
000K00030@0002D00P7K00006`000`40000S0081g@0001/000<100008P000`40003M00006`000`40
003o00<0000K00030@0001`00`7S00006`020A/00P7V00006`000`40000I00030@000>H0000K0003
0@000?l00`0001/000<10000o`0300006`000`40000C0081k@0001/00P4B0081k`0001/000<10000
40000`40003_00006`000`40003o00<0000K00030@0003X00`4i00@10`020CL0104200<1=P040@<0
0P4400006`000`40000:0081<@000`40000h00050@0000400P000`40000f00030@0000@000<10000
<`000`40000300040@000@<0000K00030@0000P00P4c00030@0003P000D100000@0200030@0003H0
00<1000010000`40000d00030@00008000@100010`0001/00P470081<P030C/000D100000@020003
0@0003H000@100000`4h00050@0000400P000`40000100006`000`40000j00030@0003/000D10000
0@0200030@0003H000D100000@0k00040@000@8000<100000@0001/000<10000>P000`40000i00<1
0`001040004f00<10`000`40000f00040@000@8000@100010`0001/000@100000P4g00@1>P000`40
00020081>@00104000040CH00P440081100001/000@10041o`020000503o0@d1000K00030@0000T0
00<100002P000`40000:00030@0000T000<100002P000`40000:00030@0000T000<100002P000`40
000:00030@0000T000<100002P000`40000:00030@0000T000<100002P000`40000:00030@0000T0
00<100002P000`40000:00030@0000T000<100002P000`40000500006`000`40000l00030@0003`0
00<10000?@000`40000l00030@0000D0000K00030@000?l00`0001/000<10000o`030000o`0Q0000
o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.15729, -2.9778, 0.0789455,
   0.0178573}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(phaseResponse2\  = \ 
      Plot[\((phase[r\ , i\ , c\ , d\ , n\ , m\ , \ w]\  /. \ sub2)\), {w, 0, 
          20}, PlotRange -> All]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0476191 0.603319 0.224023 [
[.2619 .59082 -3 -9 ]
[.2619 .59082 3 0 ]
[.5 .59082 -6 -9 ]
[.5 .59082 6 0 ]
[.7381 .59082 -6 -9 ]
[.7381 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[.01131 .04326 -24 -4.5 ]
[.01131 .04326 0 4.5 ]
[.01131 .15527 -12 -4.5 ]
[.01131 .15527 0 4.5 ]
[.01131 .26728 -24 -4.5 ]
[.01131 .26728 0 4.5 ]
[.01131 .3793 -12 -4.5 ]
[.01131 .3793 0 4.5 ]
[.01131 .49131 -24 -4.5 ]
[.01131 .49131 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(5)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(10)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(15)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(20)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .04326 m
.03006 .04326 L
s
[(-2.5)] .01131 .04326 1 0 Mshowa
.02381 .15527 m
.03006 .15527 L
s
[(-2)] .01131 .15527 1 0 Mshowa
.02381 .26728 m
.03006 .26728 L
s
[(-1.5)] .01131 .26728 1 0 Mshowa
.02381 .3793 m
.03006 .3793 L
s
[(-1)] .01131 .3793 1 0 Mshowa
.02381 .49131 m
.03006 .49131 L
s
[(-0.5)] .01131 .49131 1 0 Mshowa
.125 Mabswid
.02381 .06566 m
.02756 .06566 L
s
.02381 .08807 m
.02756 .08807 L
s
.02381 .11047 m
.02756 .11047 L
s
.02381 .13287 m
.02756 .13287 L
s
.02381 .17767 m
.02756 .17767 L
s
.02381 .20008 m
.02756 .20008 L
s
.02381 .22248 m
.02756 .22248 L
s
.02381 .24488 m
.02756 .24488 L
s
.02381 .28969 m
.02756 .28969 L
s
.02381 .31209 m
.02756 .31209 L
s
.02381 .33449 m
.02756 .33449 L
s
.02381 .35689 m
.02756 .35689 L
s
.02381 .4017 m
.02756 .4017 L
s
.02381 .4241 m
.02756 .4241 L
s
.02381 .4465 m
.02756 .4465 L
s
.02381 .4689 m
.02756 .4689 L
s
.02381 .51371 m
.02756 .51371 L
s
.02381 .53611 m
.02756 .53611 L
s
.02381 .55851 m
.02756 .55851 L
s
.02381 .58092 m
.02756 .58092 L
s
.02381 .02086 m
.02756 .02086 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .57992 L
.10458 .55444 L
.14415 .53059 L
.18221 .50775 L
.22272 .48357 L
.26171 .46045 L
.30316 .43604 L
.34309 .41269 L
.3815 .39037 L
.42237 .36675 L
.46172 .3441 L
.49955 .32236 L
.53984 .29917 L
.57861 .27676 L
.61984 .25272 L
.65954 .22925 L
.69774 .20625 L
.73838 .18119 L
.77751 .15634 L
.81909 .12899 L
.85916 .10157 L
.89771 .0741 L
.93871 .04364 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000?l0
8@000?l08@0001/000<10000o`0300006`000`40003o00<0000K00030@000?l00`0001/000<10000
o`0300006`000`40003j00030@0000D0000K0081n@020@P0000K00030@000?L000<10000200001/0
00<10000m@020@/0000K00030@000?@000<100002`0001/000<10000l`000`40000<00001`040@<0
00<100000P030@D000<10000l@020@l0000700030@0000`000<100000P020O4000<100003`0000P0
00<100002`000`40000200030@000>l000<10000400000030041008110000`40000700<11@000`40
003]00814`0000X000<100001P000`40000500030@000>`000<100004`0000L000@1000120000`40
000500030@000>/000<10000500000P00P4900@110000`40003Z00030@0001D0000K0081jP000`40
000F00006`000`40003W00816@0001/000<10000iP000`40000I00006`000`40003U00030@0001X0
000K00030@000><00P4M00006`000`40003R00030@0001d0000K0081h@020B00000K00030@000=l0
00<10000800001/000<10000gP000`40000Q00006`000`40003L0081900001/000<10000f`000`40
000T00006`000`40003I00819`0001/00P7I00030@0002L0000K00030@000=H00P4Z00006`000`40
003D0081;00001/000<10000d`000`40000/00006`000`40003A0081;`0001/000<10000d0000`40
000_00006`020Ll00P4b00006`000`40003=00030@000380000K00030@000</00P4e00006`000`40
00390081=`0001/000<10000b0000`40000g00004`040@@000<10000aP020CX0000C00030@0000D0
0P7600030@0003X0000D00030@0000@000<10000``020Cd0000=00@110000`40000300030@000<80
00<10000?@0001H000<100000P000`4000300081@00001<000@1000110000`40002o00030@000400
000D00811@000`40002n00030@000440000K0081_@020D@0000K00030@000;/000<10000A00001/0
00<10000^@020DL0000K00030@000;P000<10000A`0001/000<10000]P020DX0000K00030@000;@0
0P5<00006`020K@000<10000C00001/000<10000/@020Dl0000K00030@000;0000<10000C`0001/0
00<10000[P020E80000K00030@000:`00P5D00006`000`40002[00030@0005@0000K0081ZP020EL0
000K00030@000:L00P5I00006`000`40002V00030@0005T0000K00030@000:@00P5L00006`000`40
002R0081GP0001/000<10000X0020F00000K0081W`020F80000K00030@0009`00P5T00006`000`40
002K00030@0006@0000K00030@0009T00P5W00006`000`40002G0081J@0000L0104300030@000080
0`4500030@0009D00P5[00002@000`40000:00030@0000800P6D0081K@0000T000<100002P000`40
000200030@0009400P5_000000<00@400P4400030@0000L00`4500030@00090000<10000K`0000T0
00<100001`000`40000500030@0008h00P5b00001`030@T000<100001@000`40002<0081M00000T0
00<100001`040@@000<10000R`000`40001d00006`020HX00P5g00006`000`4000270081N@0001/0
00<10000QP000`40001i00006`000`4000240081O00001/000<10000P`000`40001l00006`000`40
00210081O`0001/00P600081P@0001/000<10000OP000`40002100006`000`40001l0081Q00001/0
00<10000NP020HH0000K00030@0007P00P6800006`000`40001f0081RP0001/00P5e0081S00001/0
00<10000LP020Hh0000K00030@00074000<10000SP0001/000<10000K`020I40000K00030@0006d0
0P6C00006`000`40001/00030@0009<0000K0081J`020IH0000K00030@0006P00P6H00006`000`40
001W00030@0009P0000K00030@0006D00P6K00004`040@@000<10000I0000`40002K00005@000`40
000300030@0006800P6N00005@000`4000030081H@020J00000=00@110000`40000300030@0005l0
00<10000X00001D000<100000`000`40001M0081X`0001<00`4500030@0005`000<10000X`0001D0
00<100000`000`40001J0081YP0001/000<10000F0020JP0000K0081F0000`40002X00006`000`40
001E0081Z`0001/000<10000D`020Jd0000K00030@00058000<10000[@0001/000<10000D0020K00
000K00030@0004h00P6b00006`020Dd00P6d00006`000`40001:0081]P0001/000<10000B0020KP0
000K00030@0004L000<10000^00001/000<10000A@020K/0000K00030@0004<00P6m00006`020D80
0P6o00006`000`40000o0081`@0001/000<10000?@020L<0000K00030@0003`000<10000``0001/0
00<10000>P020LH0000K00030@0003P00P7800006`020CP000<10000b00001/000<10000=@020L/0
000K00030@0003<00P7=00006`000`40000b00030@000<d00008008110000`40000200<11@000`40
000`0081d00000L000@100012`000`40000200030@0002l000<10000d00000L000@100012`000`40
00020081;P020M<000000`010@020@8000@1000120030@D000<10000:`020MD0000700040@000@P0
00<100001@000`40000Z00030@000=D0000700040@000@P000<100001@000`40000X0081f00000P0
0P4900@110000`40000W00030@000=P0000K00819P020M/0000K00030@0002<00P7M00006`000`40
000R00030@000=d0000K00030@0002000P7P00006`000`40000N0081hP0001/000<100007@000`40
003R00006`020A`00P7U00006`000`40000I0081i`0001/000<100005`020NT0000K00030@0001D0
0P7[00006`000`40000C0081k@0001/000<100004P000`40003]00006`020A400P7`00006`000`40
000?00030@000?00000K00030@0000d00P7c00006`000`40000;0081m@0001/000<100002P000`40
000]00<1>@040@<00P4g00@10P030CH010430081100001/000<1000020020C<000<10000>0001@40
0001008000<10000=P000`40000400030@0003<000<100000`001040004300006`020@P000<10000
<`000`40000h00050@0000400P000`40000f00030@0000@000<10000=0000`40000200040@000@<0
000K00030@0000D00P4c00<1>`001@400001008000<10000=P00104000030CP000D100000@020003
0@000040000K00030@0000<00P4e00030@0003/000D100000@0200030@0003H000D100000@0k0004
0@000@8000<100000@0001/000<100000P000`40000e00030@0003T00`4300040@000CH00`430003
0@0003H000@100010P001040004300006`000`4000020CP0104j00030@0000800P4i00040@0000@1
=P020@@00P4400006`030Ol00`0001@0o`4=0@006`000`40000900030@0000X000<100002P000`40
000900030@0000X000<100002P000`40000900030@0000X000<100002P000`40000900030@0000X0
00<100002P000`40000900030@0000X000<100002P000`40000900030@0000X000<100002P000`40
000900030@0000X000<100001@0001/000<10000?0000`40000l00030@0003d000<10000?0000`40
000500006`000`40003o00<0000K00030@000?l00`000?l08@000?l08@000?l08@000?l08@000?l0
8@000?l08@000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.15729, -2.79831, 
  0.0789455, 0.0167809}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(phaseResponses\  = 
      Show[phaseResponse1, \ phaseResponse2, \ 
        AxesLabel -> {"\<\[Omega]\>", "\<\>"}]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0476191 0.603319 0.21052 [
[.2619 .59082 -3 -9 ]
[.2619 .59082 3 0 ]
[.5 .59082 -6 -9 ]
[.5 .59082 6 0 ]
[.7381 .59082 -6 -9 ]
[.7381 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[1.025 .60332 0 -7.5 ]
[1.025 .60332 10 7.5 ]
[.01131 .07702 -24 -4.5 ]
[.01131 .07702 0 4.5 ]
[.01131 .18228 -12 -4.5 ]
[.01131 .18228 0 4.5 ]
[.01131 .28754 -24 -4.5 ]
[.01131 .28754 0 4.5 ]
[.01131 .3928 -12 -4.5 ]
[.01131 .3928 0 4.5 ]
[.01131 .49806 -24 -4.5 ]
[.01131 .49806 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(5)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(10)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(15)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(20)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
69.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.02381 .07702 m
.03006 .07702 L
s
[(-2.5)] .01131 .07702 1 0 Mshowa
.02381 .18228 m
.03006 .18228 L
s
[(-2)] .01131 .18228 1 0 Mshowa
.02381 .28754 m
.03006 .28754 L
s
[(-1.5)] .01131 .28754 1 0 Mshowa
.02381 .3928 m
.03006 .3928 L
s
[(-1)] .01131 .3928 1 0 Mshowa
.02381 .49806 m
.03006 .49806 L
s
[(-0.5)] .01131 .49806 1 0 Mshowa
.125 Mabswid
.02381 .09807 m
.02756 .09807 L
s
.02381 .11912 m
.02756 .11912 L
s
.02381 .14017 m
.02756 .14017 L
s
.02381 .16123 m
.02756 .16123 L
s
.02381 .20333 m
.02756 .20333 L
s
.02381 .22438 m
.02756 .22438 L
s
.02381 .24543 m
.02756 .24543 L
s
.02381 .26649 m
.02756 .26649 L
s
.02381 .30859 m
.02756 .30859 L
s
.02381 .32964 m
.02756 .32964 L
s
.02381 .35069 m
.02756 .35069 L
s
.02381 .37175 m
.02756 .37175 L
s
.02381 .41385 m
.02756 .41385 L
s
.02381 .4349 m
.02756 .4349 L
s
.02381 .45595 m
.02756 .45595 L
s
.02381 .47701 m
.02756 .47701 L
s
.02381 .51911 m
.02756 .51911 L
s
.02381 .54016 m
.02756 .54016 L
s
.02381 .56121 m
.02756 .56121 L
s
.02381 .58227 m
.02756 .58227 L
s
.02381 .05597 m
.02756 .05597 L
s
.02381 .03491 m
.02756 .03491 L
s
.02381 .01386 m
.02756 .01386 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .60332 m
.06244 .58302 L
.10458 .56085 L
.14415 .53998 L
.18221 .51983 L
.22272 .49829 L
.26171 .47741 L
.30316 .45505 L
.34309 .43329 L
.3815 .41212 L
.42237 .3893 L
.46172 .36697 L
.49955 .34511 L
.53984 .32136 L
.57861 .29795 L
.61984 .27237 L
.65954 .24698 L
.69774 .22178 L
.73838 .19405 L
.77751 .16642 L
.81909 .13606 L
.85916 .10591 L
.89771 .07622 L
.93871 .04416 L
.97619 .01472 L
s
[ ] 0 setdash
.02381 .60332 m
.06244 .58133 L
.10458 .55739 L
.14415 .53497 L
.18221 .51351 L
.22272 .49079 L
.26171 .46906 L
.30316 .44613 L
.34309 .42418 L
.3815 .40321 L
.42237 .38101 L
.46172 .35973 L
.49955 .33929 L
.53984 .31751 L
.57861 .29645 L
.61984 .27386 L
.65954 .25179 L
.69774 .23018 L
.73838 .20663 L
.77751 .18328 L
.81909 .15758 L
.85916 .13181 L
.89771 .106 L
.93871 .07738 L
.97619 .05019 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000?l0
8@000?l08@000?l08@000?l08@000?l08@0001/000<10000o`0300006`000`40003o00<0000K0003
0@000?l00`0001/00P7o00@0000K00030@000>X000<100005@0001/000<10000o`0300006`000`40
003o00<0000K00030@000>H000<100006@0001/000<10000i0020A`0000K0081i0000`40000L0000
6`000`40003R00030@0001d0000K00030@000?l00`0001/000<10000o`0300006`000`40003N0003
0@0000T000<100005@0001/00P7M00812P020AP0000K00030@000=/000<100002@000`40000H0000
6`000`40003J00030@0000P00P4K00006`000`40003T00030@0001/0000700@10`000`40000200<1
1@000`40003R00817P0000L000<1000030000`4000020081e`000`40000800030@0001h000080003
0@0000/000<100000P000`40003D00812@020B4000000`010@020@@000<100001`030@D000<10000
d`000`40000800030@000240000:00030@0000H000<100001@000`40003B00030@0000L00P4T0000
1`001040004800030@0000D000<10000f`000`40000T000020020@T010440081f`000`40000U0000
6`000`40003>00030@0000L00P4X00006`000`40003=00030@0000L000<10000:00001/000<10000
b`020@P00P4[00006`000`40003:00030@0000L000<10000:`0001/000<10000dP020Bh0000K0081
dP000`40000^00006`000`40003@00030@0002l0000K00030@000<H000<100001@020C80000K0003
0@000<@00P4700030@000380000K00030@000<<000<100001@020CD0000K0081``000`4000040081
=`0001/000<10000b0000`40000g00006`000`40002n00030@0000D00P4j00006`000`40002l0081
1P020C`0000K00030@000;/000<100001@000`40000l00006`020K/000<1000010020Cl0000K0003
0@000<0000<10000?`0001/000<10000_P020D80000K00030@000;H000<1000010000`4000120000
4`040@@000<10000]0020@H000<10000@`0001<000<100001@020K@000<1000010020DH0000D0003
0@0000@000<10000/P000`40000400030@0004H0000=00@110000`40000300030@000;L00P590000
5P000`40000200030@000;D00P5;00004`001040004400030@000:h000<100000`000`40001;0000
50020@D000<10000[0020@@00P5>00006`020J`000<100000P020E00000K00030@000:X000@10000
0P5B00006`000`40002/0081E00001/000<10000ZP020EH0000K00030@000:D00P400`010@1H0000
6`020J@00P400`010@1J00006`000`40002R00040@000E`0000K00030@000:<00P5M00006`000`40
002Q0081G`0001/000<10000WP000`400@1Q00006`020Id0105R00006`000`40002J00@1I00001/0
00<10000V@030FH0000K00030@0009P00P5X00006`000`40002F0081JP0001/000<10000U0020F`0
000K0081T`020Fh0000K00030@00094000<10000KP0001/000<10000S`020G40000700@10`000`40
000200<11@000`40002=0081L`0000T000<100002P000`40000200030@0008`00P5d00002@000`40
000:00030@0000800P6;00<1M@0000030041008110000`40000700<11@000`40002800<1M`0000T0
00<100001`000`40000500030@0008H00`5i00001`030@T000<100001@000`4000240081O00000T0
00<100001`040@@000<10000PP030Gd0000K0081P@040Gh0000K00030@0007h00P400`01001o0000
6`000`40001m00040@000H40000K00030@0007/00P6500006`000`40001i008100<00@00Q00001/0
0P5i00040@010HH0000K00030@0007H0106800006`000`40001d008100<00@00R@0001/000<10000
L`000`40002<00006`000`40001a00<1SP0001/000<10000K`040Hl0000K0081KP020@0300400900
000K00030@0006/00P4200030@000900000K00030@0006T00P6G00006`000`40001W008100<00@00
UP0001/000<10000I@020@800P6G00006`020F@00P420081V@0001/000<10000H@020@<000<10000
V@0001/000<10000H0000`40002O00006`000`40001N008100<00@40W`0001<0104400030@0005`0
0P4200030@0009l0000E00030@0000<00P5L00030@000081XP0001D000<100000`000`40001I0081
0P000`40002R00003@040@@000<100000`000`40001G0081Z@0001D000<100000`000`40001E0081
0P000`40002V00004`030@D000<10000D`020@800P6Y00005@000`4000030081DP020@<000<10000
Z@0001/000<10000C`020@@000<10000ZP0001/000<10000C@020K<0000K00030@0004/00P420081
/@0001/000<10000B@020@800P6c00006`000`40001700810`000`40002c00006`020DH00P6k0000
6`000`4000130081_@0001/000<10000@P00104000020KX0000K00030@0004000P420081_00001/0
00<10000?P020@<000<10000_00001/00P4n00030@000<80000K00030@0003/00P7500006`000`40
000i00810`020L80000K00030@0003L00P430081a00001/000<10000=@020@<00P7600006`020C@0
0P7=00006`000`40000a00810`000`40003900006`000`40000_00810`020L`0000K00030@0002h0
00<100000P000`40003<000020020@@000<100000P030@D000<10000;0020@@000<10000c@0000L0
00@100012`000`4000020081:`020MH0000700040@000@/000<100000P000`40000Y00030@000081
e0000003004100810P001040004800<11@000`40000W008100<00@40eP0000L000@1000120000`40
000500030@0002D00P4200030@000=H0000700040@000@P000<100001@000`40000T00030@000=/0
000800812@040@@000<100008P020Mh0000K00818P0010400@7M00006`000`40000O00@1g`0001/0
00<100007P000`400@3Q00006`000`40000L0081i00001/000<100006P020NH0000K00816@040NH0
000K00030@0001H0107X00006`000`40000D008100<00@00j@0001/000<100004P020Nh0000K0003
0@0001400`7^00006`020A000`7`00006`000`40000=00<1lP0001/000<100002`020BT00`4e00@1
0`020C<0104200<1<P040@<00P4D00006`000`4000090081;P000`40000d00050@0000400P000`40
000b00030@0000@000<10000;`000`40000300040@000A<0000K00030@0000L0104^00030@0003@0
00D100000@0200030@00038000<1000010000`40000`00030@00008000@100014`0001/00P4700<1
;@030CL000D100000@0200030@00038000@100000`4d00050@0000400P000`40000A00006`000`40
000400<1;`000`40000g00050@0000400P000`40000b00050@000040=`001040004200030@000140
000K00030@0000<000<10000<0000`40000e00<10`001040004b00<10`000`40000b00040@000@80
00@100014`0001/000@100000P4c00@1=P000`4000020081=@00104000040C800P44008130040@@0
000K00040@010OP000H10001004300006`030OT000H10001004300005@3j0@P000<100000P000`40
000100006`000`40000900030@0000P000<100002@000`40000900030@0000T000<100002@000`40
000900030@0000T000<100002@000`40000800030@0000T000<100002@000`40000900030@0000T0
00<100002@000`40000900030@0000T000<100002@000`40000800030@0000T000<100003@001@40
000100<0000K00030@000?l00`0001/000<10000o`030000o`0Q0000o`0Q0000o`0Q0000o`0Q0000
o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.28198, -3.04533, 0.084141,
   0.0190325}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Step response", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stepResponse1\  = 
      Plot[\((stepResponse[r\ , i\ , c\ , d\ , n\ , m\ , \ t]\  /. \ sub1)
          \), {t, 0, 1}, PlotStyle -> {Dashing[{.02, .02}]}, 
        PlotRange -> All]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.531088 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .12093 -18 -4.5 ]
[.01131 .12093 0 4.5 ]
[.01131 .22715 -18 -4.5 ]
[.01131 .22715 0 4.5 ]
[.01131 .33337 -18 -4.5 ]
[.01131 .33337 0 4.5 ]
[.01131 .43959 -18 -4.5 ]
[.01131 .43959 0 4.5 ]
[.01131 .5458 -6 -4.5 ]
[.01131 .5458 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12093 m
.03006 .12093 L
s
[(0.2)] .01131 .12093 1 0 Mshowa
.02381 .22715 m
.03006 .22715 L
s
[(0.4)] .01131 .22715 1 0 Mshowa
.02381 .33337 m
.03006 .33337 L
s
[(0.6)] .01131 .33337 1 0 Mshowa
.02381 .43959 m
.03006 .43959 L
s
[(0.8)] .01131 .43959 1 0 Mshowa
.02381 .5458 m
.03006 .5458 L
s
[(1)] .01131 .5458 1 0 Mshowa
.125 Mabswid
.02381 .04127 m
.02756 .04127 L
s
.02381 .06782 m
.02756 .06782 L
s
.02381 .09438 m
.02756 .09438 L
s
.02381 .14749 m
.02756 .14749 L
s
.02381 .17404 m
.02756 .17404 L
s
.02381 .2006 m
.02756 .2006 L
s
.02381 .2537 m
.02756 .2537 L
s
.02381 .28026 m
.02756 .28026 L
s
.02381 .30681 m
.02756 .30681 L
s
.02381 .35992 m
.02756 .35992 L
s
.02381 .38648 m
.02756 .38648 L
s
.02381 .41303 m
.02756 .41303 L
s
.02381 .46614 m
.02756 .46614 L
s
.02381 .49269 m
.02756 .49269 L
s
.02381 .51925 m
.02756 .51925 L
s
.02381 .57236 m
.02756 .57236 L
s
.02381 .59891 m
.02756 .59891 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01473 L
.03163 .01474 L
.03279 .01475 L
.03395 .01477 L
.0352 .01481 L
.03638 .01485 L
.03746 .0149 L
.03873 .01497 L
.04011 .01508 L
.04262 .01534 L
.04396 .01552 L
.04523 .01573 L
.04759 .01621 L
.05014 .0169 L
.0529 .01785 L
.05787 .02025 L
.06244 .02334 L
.0675 .02792 L
.07221 .03341 L
.08293 .05076 L
.09338 .07461 L
.10458 .10776 L
.14594 .28017 L
.16664 .37576 L
.18579 .45576 L
.20437 .5189 L
.21387 .54444 L
.22412 .56657 L
.22906 .57527 L
.23427 .58305 L
.2391 .58904 L
.24359 .59359 L
.24781 .59702 L
.25232 .59981 L
.25489 .60102 L
.25732 .60192 L
.2595 .60253 L
.26073 .6028 L
.26187 .60299 L
.26312 .60315 L
.26431 .60326 L
.26538 .60331 L
.26654 .60332 L
.2678 .60328 L
Mistroke
.26851 .60324 L
.26914 .60319 L
.27039 .60305 L
.27156 .60287 L
.27383 .60242 L
.27592 .60188 L
.28063 .60024 L
.28542 .59804 L
.29067 .59511 L
.30127 .5879 L
.32245 .57081 L
.34175 .55549 L
.35134 .54882 L
.36177 .54261 L
.37154 .5379 L
.38071 .53451 L
.38563 .5331 L
.39013 .53205 L
.39513 .53115 L
.39776 .53078 L
.40052 .53047 L
.40304 .53026 L
.40445 .53017 L
.40573 .5301 L
.40692 .53005 L
.40822 .53001 L
.40944 .52999 L
.41057 .52998 L
.41188 .52998 L
.41311 .53 L
.41381 .53001 L
.41446 .53003 L
.4159 .53008 L
.41729 .53014 L
.4188 .53023 L
.42154 .53042 L
.42638 .5309 L
.43092 .53147 L
.44129 .53316 L
.46229 .53758 L
.48074 .54169 L
.50095 .5456 L
.51062 .54709 L
.52096 .54836 L
.52668 .54891 L
.53188 .54933 L
.53711 .54966 L
.54205 .54989 L
.54667 .55005 L
.5493 .55012 L
Mistroke
.55176 .55016 L
.55309 .55018 L
.55435 .55019 L
.55548 .55019 L
.55671 .5502 L
.55742 .5502 L
.55805 .5502 L
.55879 .5502 L
.55948 .5502 L
.56071 .55019 L
.5614 .55018 L
.56204 .55018 L
.56426 .55015 L
.56632 .55011 L
.57101 .55001 L
.57559 .54986 L
.58049 .54967 L
.60174 .54855 L
.62187 .54731 L
.6401 .54627 L
.65048 .54577 L
.66022 .54538 L
.66974 .54507 L
.68001 .54483 L
.68535 .54474 L
.68826 .54471 L
.69097 .54468 L
.69349 .54465 L
.69577 .54464 L
.69831 .54462 L
.6997 .54462 L
.70102 .54461 L
.70218 .54461 L
.70342 .54461 L
.70459 .54461 L
.70566 .54461 L
.70691 .54461 L
.70761 .54461 L
.70827 .54461 L
.70947 .54461 L
.71075 .54462 L
.71354 .54463 L
.71616 .54465 L
.72105 .54468 L
.72992 .54478 L
.73951 .54491 L
.75911 .54522 L
.78058 .54558 L
.79047 .54572 L
.80106 .54585 L
Mistroke
.81098 .54595 L
.82014 .54602 L
.825 .54605 L
.83035 .54608 L
.83573 .5461 L
.83868 .54611 L
.84144 .54612 L
.84403 .54612 L
.84531 .54612 L
.8465 .54612 L
.84766 .54613 L
.84872 .54613 L
.84989 .54613 L
.85114 .54613 L
.85179 .54613 L
.85248 .54613 L
.85372 .54613 L
.85441 .54613 L
.85505 .54613 L
.85651 .54613 L
.85779 .54613 L
.85895 .54612 L
.86157 .54612 L
.86638 .54611 L
.87148 .5461 L
.88065 .54607 L
.90141 .54598 L
.91957 .5459 L
.93915 .54582 L
.94856 .54579 L
.95847 .54576 L
.96693 .54574 L
.97619 .54573 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000480
0P4400030@000080104U008110000`40000400030@0002<00P4400030@0000<00P4V008110000`40
00030081:`040@H0001100040@000@P000<100009@001040004:00030@00028000@1000120001040
004T00040@000@P000@10001;0000`4000050000@@001040004900030@0002@000@100011`050B<0
00@1000120001040004T00040@000@P000@10001;0000`4000050000@@001040004:00030@0002<0
00@100011`001040004T00040@000@P00`4U00040@000@T00P4]00030@0000D0000E00030@0002T0
00@100012`000`40000R00040@000@P000<1004090001040004800030@0002D000@1000120001040
004/00030@0000D0000E00030@0002T000@1000120001040004T00040@000@T00P4T00040@000@P0
00<100009@001040004800040@000BX00`4700005@000`40000Z00812P020BH00P4;00030@0002<0
0P4:00<19@020@X00P4]00030@0000D0000E00030@000?l02@0000h0o`4C0@005@000`40000300<1
10000`40000:00030@0000X000<100002P000`40000:00030@0000X000<100002P000`40000:0003
0@0000X000<100002@000`40000:00030@0000X000<100002P000`40000:00030@0000X000<10000
2P000`40000:00030@0000X000<100002P000`40000:00030@0000D0000E00030@00034000<10000
<@000`40000`00030@00034000<10000<@000`40000500005@000`40003o00T0000E00030@0000T0
00<10000o00001D000<100002P000`40003k00005@000`40000;00030@000?X0000E008130000`40
003j00005@000`40000<00030@000?T0000E00030@0000`000<10000n@0001D000<10000o`090000
5@000`40003o00T0000E00030@000?l02@0001D000<100003P000`40003g00005@000`40000?0003
0@000?H0000E008140000`40003f00005@000`40000@00030@000?D0000E00030@00010000<10000
m@0001D000<100004@000`40003d00005@000`40000A00030@000?@0000E00030@000?l02@0001D0
00<10000o`0900005@020Ol02P0001D000<10000o`0900005@000`40000B00030@000?<0000E0003
0@0001<000<10000lP0001D000<100004`000`40003b00005@000`40000D00030@000?4000020081
10000`40000200@110000`40000D00030@000?4000001@01000100P000<100001@030A@000<10000
l@000005004000402@000`40000400030@000?l02@000005004000402P000`40000300030@000?l0
2@000005004000402`000`40000200030@000?l02@0000050040004020001040004400030@000?l0
2@0000800P4:00811@000`40000E00030@000?00000E00030@0001D000<10000l00001D00P4F0003
0@000?00000E00030@0001H000<10000k`0001D000<100005P000`40003_00005@000`40000F0003
0@000>l0000E00030@0001H000<10000k`0001D000<10000o`0900005@000`40003o00T0000E0003
0@000?l02@0001D00P7o00X0000E00030@0001P000<10000k@0001D000<1000060000`40003]0000
5@000`40000H00030@000>d0000E00030@0001T000<10000k00001D000<100006@000`40003/0000
5@000`40000I00030@000>`0000E0081o`0:00005@000`40003o00T0000E00030@000?l02@0001D0
00<10000o`0900005@000`40000J00030@000>/0000E00030@0001X000<10000j`0000800P440003
0@0000@000<100000`000`40000J00030@000>/000001@01000100X000<100000`030A/000<10000
jP000005004000401`050@@000<100006`000`40003Z000000D00@000@0700040@000@D000<10000
6`000`40003Z000000D00@000@0800030@0100D000<100006`000`40003Z000000D00@000@090081
1@000`40003o00T0000200812`000`40000300030@000?l02@0001D000<10000o`0900005@020Ol0
2P0001D000<100007@000`40003X00005@000`40000M00030@000>P0000E00030@0001d000<10000
j00001D000<100007P000`40003W00005@000`40000N00030@000>L0000E00030@0001h000<10000
i`0001D00P7o00X0000E00030@000?l02@0001D000<10000o`0900005@000`40003o00T0000E0003
0@000?l02@0001D000<100007`000`40003V00005@000`40000O00030@000>H0000E00030@0001l0
00<10000iP0001D00P4Q00030@000>D0000E00030@00020000<10000i@0001D000<1000080000`40
003U00005@000`40003o00T0000E00030@000?l02@0001D000<10000o`0900000P020@@000<10000
0`020@D000<10000o`09000000D00@000@0800040@000@@00`4Q00030@000>@000001@01000100P0
00@1000110000`40000Q00030@000>@000001@01000100P00`4500030@00024000<10000i0000005
0040004020000`40000500030@00028000<10000h`0000050040004020000`40000500030@000280
00<10000h`0000800P4:00<110000`40000R00030@000><0000E00030@00028000<10000h`0001D0
0P7o00X0000E00030@000?l02@0001D000<10000o`0900005@000`40003o00T0000E00030@0002@0
00<10000h@0001D000<1000090000`40003Q00005@000`40000T00030@000>40000E00819P000`40
003P00005@000`40000U00030@000>00000E00030@0002D000<10000h00001D000<10000o`090000
5@000`40003o00T0000E00030@000?l02@0001D000<10000o`0900005@000`40000V00030@000=l0
000E00819`000`40003O00005@000`40000V00030@000=l0000E00030@0002L000<10000gP0001D0
00<100009`000`40003N00005@000`40000W00030@000=h00002008110000`40000300811@000`40
000W00030@000=h000001@01000100P000@1000110000`40003o00T000001@01000100P000@10001
10030Ol02@000005004000402@020@D000<10000o`09000000D00@000@0800040@000@@000<10000
o`09000000D00@000@0800040@000@@000<10000:@000`40003L00000P020@X00P4500030@0002T0
00<10000g00001D000<10000:@000`40003L00005@000`40000Z00030@000=/0000E0081:`000`40
003K00005@000`40000Z00030@000=/0000E00030@000?l02@0001D000<10000o`0900005@000`40
003o00T0000E00030@000?l02@0001D000<10000;0000`40003I00005@020Bd000<10000f@0001D0
00<10000;0000`40003I00005@000`40000]00030@000=P0000E00030@0002d000<10000f00001D0
00<10000;@000`40003H00005@000`40000]00030@000=P0000E00030@000?l02@0001D00P7o00X0
000E00030@000?l02@0001D000<10000o`0900005@000`40000_00030@000340106Q00005@000`40
000`00030@0002h00`4800@1V00001D000<10000<0000`40000m0081UP0000d0104400030@000340
00<100009`020AT00P6@00003`000`40000300030@00034000<1000090030Ad01@4c00H11@060DL0
000?00030@0000<00`4a00030@0002<000<100009`060A<01`4400H16`060@P01P4500H11@060@@0
1`4400811`0000l000<100000`000`40002600030@0000<000<100001`5b00003`000`4000030003
0@000?l02@0000d00`4500030@00058000<10000/`0000l000<100000`000`40001@0081]P0001D0
00<10000<`000`40000I00030@000;H0000E00030@0003@000<100005`000`40002g00005@020CD0
00<100005`000`40002g00005@000`40000e00030@000=00000E00030@0003H000<10000c`0001D0
00<10000=P000`40000@0081_@0001D000<10000B0000`40002m00005@000`40001700030@000;h0
000E00030@0003X000<1000020020L40000E0081>`020L`0000E00030@0003`01@7700005@000`40
003o00T0000E00030@000?l02@0001D000<10000o`0900005@000`40003o00T00000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, -0.0871671, 
  0.00385924, 0.00692063}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stepResponse2\ \  = 
      Plot[\((stepResponse[r\ , i\ , c\ , d\ , n\ , m\ , \ t]\  /. \ sub2)
          \), {t, 0, 1}, PlotRange -> All]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.564046 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .12752 -18 -4.5 ]
[.01131 .12752 0 4.5 ]
[.01131 .24033 -18 -4.5 ]
[.01131 .24033 0 4.5 ]
[.01131 .35314 -18 -4.5 ]
[.01131 .35314 0 4.5 ]
[.01131 .46595 -18 -4.5 ]
[.01131 .46595 0 4.5 ]
[.01131 .57876 -6 -4.5 ]
[.01131 .57876 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12752 m
.03006 .12752 L
s
[(0.2)] .01131 .12752 1 0 Mshowa
.02381 .24033 m
.03006 .24033 L
s
[(0.4)] .01131 .24033 1 0 Mshowa
.02381 .35314 m
.03006 .35314 L
s
[(0.6)] .01131 .35314 1 0 Mshowa
.02381 .46595 m
.03006 .46595 L
s
[(0.8)] .01131 .46595 1 0 Mshowa
.02381 .57876 m
.03006 .57876 L
s
[(1)] .01131 .57876 1 0 Mshowa
.125 Mabswid
.02381 .04292 m
.02756 .04292 L
s
.02381 .07112 m
.02756 .07112 L
s
.02381 .09932 m
.02756 .09932 L
s
.02381 .15573 m
.02756 .15573 L
s
.02381 .18393 m
.02756 .18393 L
s
.02381 .21213 m
.02756 .21213 L
s
.02381 .26854 m
.02756 .26854 L
s
.02381 .29674 m
.02756 .29674 L
s
.02381 .32494 m
.02756 .32494 L
s
.02381 .38134 m
.02756 .38134 L
s
.02381 .40955 m
.02756 .40955 L
s
.02381 .43775 m
.02756 .43775 L
s
.02381 .49415 m
.02756 .49415 L
s
.02381 .52236 m
.02756 .52236 L
s
.02381 .55056 m
.02756 .55056 L
s
.02381 .60696 m
.02756 .60696 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01473 L
.03163 .01474 L
.03279 .01475 L
.03395 .01478 L
.0352 .01481 L
.03638 .01485 L
.03746 .0149 L
.03873 .01498 L
.04011 .01509 L
.04262 .01536 L
.04396 .01555 L
.04523 .01576 L
.04759 .01626 L
.05014 .01697 L
.0529 .01796 L
.05787 .02044 L
.06244 .02367 L
.0675 .02844 L
.07221 .03418 L
.08293 .05237 L
.09338 .07743 L
.10458 .11232 L
.14594 .2929 L
.16664 .39121 L
.18579 .47152 L
.20437 .53264 L
.21376 .55612 L
.22412 .57615 L
.22903 .58355 L
.23421 .58996 L
.23868 .59439 L
.24346 .59806 L
.24617 .59968 L
.24862 .60087 L
.25109 .60182 L
.25342 .60249 L
.25474 .60278 L
.25614 .60302 L
.25734 .60317 L
.25865 .60327 L
.25939 .6033 L
.26006 .60332 L
.26084 .60332 L
.26158 .6033 L
Mistroke
.26289 .60322 L
.26363 .60315 L
.26432 .60308 L
.26561 .6029 L
.26697 .60266 L
.26941 .6021 L
.27491 .60033 L
.27967 .59829 L
.28488 .59562 L
.3035 .58399 L
.32469 .57066 L
.33471 .56553 L
.34398 .56181 L
.34863 .56035 L
.35357 .55911 L
.35853 .55818 L
.36135 .5578 L
.36262 .55766 L
.364 .55753 L
.36512 .55744 L
.36632 .55736 L
.36758 .5573 L
.36876 .55726 L
.36994 .55723 L
.37104 .55722 L
.37204 .55723 L
.37312 .55725 L
.3743 .55728 L
.3756 .55734 L
.37696 .55742 L
.37823 .55751 L
.3805 .55771 L
.38294 .55799 L
.38821 .55877 L
.3931 .55971 L
.40415 .56243 L
.42427 .56864 L
.44449 .57505 L
.45441 .57781 L
.4635 .57999 L
.47216 .5817 L
.48164 .58314 L
.48658 .5837 L
.49118 .58411 L
.49603 .58443 L
.49875 .58456 L
.50002 .58461 L
.50122 .58464 L
.50242 .58468 L
.50352 .5847 L
Mistroke
.50474 .58472 L
.50606 .58474 L
.50732 .58475 L
.50803 .58475 L
.50869 .58475 L
.5099 .58474 L
.51118 .58473 L
.51238 .58471 L
.51367 .58469 L
.51601 .58463 L
.51829 .58456 L
.52038 .58447 L
.5252 .58423 L
.53049 .58388 L
.54117 .58301 L
.56233 .58092 L
.58161 .57906 L
.59119 .57829 L
.60161 .57759 L
.60638 .57733 L
.61145 .5771 L
.61588 .57694 L
.62054 .5768 L
.62288 .57674 L
.62544 .57669 L
.62779 .57665 L
.62992 .57663 L
.63114 .57661 L
.63245 .5766 L
.63318 .5766 L
.63385 .5766 L
.63516 .57659 L
.63629 .57659 L
.63752 .57659 L
.63882 .57659 L
.64003 .57659 L
.64116 .5766 L
.64239 .57661 L
.64464 .57662 L
.64682 .57665 L
.64884 .57667 L
.65343 .57675 L
.65831 .57686 L
.67978 .57751 L
.69997 .57822 L
.7184 .57881 L
.72885 .57907 L
.73859 .57926 L
.74355 .57933 L
.74825 .57939 L
Mistroke
.75084 .57942 L
.75366 .57944 L
.7562 .57946 L
.75858 .57947 L
.76111 .57948 L
.76246 .57949 L
.7639 .57949 L
.76462 .57949 L
.76541 .57949 L
.76616 .5795 L
.76685 .5795 L
.76815 .5795 L
.76888 .5795 L
.76954 .5795 L
.77085 .5795 L
.77205 .57949 L
.77336 .57949 L
.77475 .57949 L
.77709 .57948 L
.77966 .57947 L
.7849 .57944 L
.78986 .5794 L
.79917 .57931 L
.82008 .57907 L
.83829 .57885 L
.84866 .57875 L
.85839 .57866 L
.8679 .5786 L
.8728 .57857 L
.87816 .57855 L
.8835 .57853 L
.88641 .57852 L
.88912 .57852 L
.89042 .57851 L
.89166 .57851 L
.89278 .57851 L
.89397 .57851 L
.89527 .57851 L
.89646 .57851 L
.89775 .57851 L
.89848 .57851 L
.89916 .57851 L
.90041 .57851 L
.90111 .57851 L
.90175 .57851 L
.90298 .57851 L
.90414 .57851 L
.90675 .57851 L
.90956 .57852 L
.91471 .57853 L
Mistroke
.91944 .57854 L
.93798 .5786 L
.97619 .57875 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000480
0P4400030@000080104U008110000`40000400030@0002<00P4400030@0000<00P4V008110000`40
00030081:`040@H0001100040@000@P000<100009@001040004:00030@00028000@1000120001040
004T00040@000@P000@10001;0000`4000050000@@001040004900030@0002@000@100011`050B<0
00@1000120001040004T00040@000@P000@10001;0000`4000050000@@001040004:00030@0002<0
00@100011`001040004T00040@000@P00`4U00040@000@T00P4]00030@0000D0000E00030@0002T0
00@100012`000`40000R00040@000@P000<1004090001040004800030@0002D000@1000120001040
004/00030@0000D0000E00030@0002T000@1000120001040004T00040@000@T00P4T00040@000@P0
00<100009@001040004800040@000BX00`4700005@000`40000Z00812P020BH00P4;00030@0002<0
0P4:00<19@020@X00P4]00030@0000D0000E00030@000?l02@0000h0o`4C0@005@000`40000300<1
10000`40000:00030@0000X000<100002P000`40000:00030@0000X000<100002P000`40000:0003
0@0000X000<100002@000`40000:00030@0000X000<100002P000`40000:00030@0000X000<10000
2P000`40000:00030@0000X000<100002P000`40000:00030@0000D0000E00030@0000H000<10000
:0000`40000a00030@00030000<10000<@000`40000a00030@0000D0000E00030@0000L00P7o0000
5@000`40000900030@000?`0000E00030@0000X000<10000n`0001D000<100002`000`40003j0000
5@000`40000;00030@000?X0000E00813@000`40003i00005@000`40000<00030@000?T0000E0003
0@0000d000<10000n00001D000<100003@000`40003h00005@000`40000>00030@000?L0000E0003
0@0000h000<10000m`0001D000<100003`000`40003f00005@000`40000?00030@000?H0000E0081
4@000`40003e00005@000`40000@00030@000?D0000E00030@00010000<10000m@0001D000<10000
4@000`40003d00005@000`40000A00030@000?@0000E00030@00014000<10000m00001D000<10000
4P000`40003c00005@020A<000<10000l`0001D000<100004P000`40003c00005@000`40000B0003
0@000?<0000E00030@0001<000<10000lP0001D000<100004`000`40003b00005@000`40000C0003
0@000?80000E00030@0001<000<10000lP0000800P4400030@000080104400030@0001@000<10000
l@0000050040004020000`40000500<150000`40003a000000D00@000@0900030@0000@000<10000
50000`40003a000000D00@000@0:00030@0000<000<1000050000`40003a000000D00@000@0;0003
0@00008000<100005@000`40003`000000D00@000@0800040@000@@000<100005@000`40003`0000
0P020@X00P4500030@0001D000<10000l00001D000<100005@000`40003`00005@000`40000E0003
0@000?00000E00815`000`40003_00005@000`40000F00030@000>l0000E00030@0001H000<10000
k`0001D000<100005P000`40003_00005@000`40000G00030@000>h0000E00030@0001L000<10000
kP0001D000<100005`000`40003^00005@020AP000<10000kP0001D000<100005`000`40003^0000
5@000`40000H00030@000>d0000E00030@0001P000<10000k@0001D000<1000060000`40003]0000
5@000`40000H00030@000>d0000E00030@0001T000<10000k00001D000<100006@000`40003/0000
5@020AX000<10000k00001D000<100006@000`40003/00005@000`40000J00030@000>/0000E0003
0@0001X000<10000j`0001D000<100006P000`40003[00005@000`40000J00030@000>/000020081
10000`40000400030@0000<000<100006P000`40003[000000D00@000@0:00030@0000<000<10000
6`000`40003Z000000D00@000@0700D110030A/000<10000jP000005004000401`00104000450003
0@0001/000<10000jP0000050040004020000`400@0500030@0001/000<10000jP00000500400040
2@020@D000<1000070000`40003Y00000P020@/000<100000`000`40000L00030@000>T0000E0003
0@0001`000<10000j@0001D000<1000070000`40003Y00005@020Ad000<10000j@0001D000<10000
7@000`40003X00005@000`40000M00030@000>P0000E00030@0001d000<10000j00001D000<10000
7@000`40003X00005@000`40000N00030@000>L0000E00030@0001h000<10000i`0001D000<10000
7P000`40003W00005@020Al000<10000i`0001D000<100007P000`40003W00005@000`40000O0003
0@000>H0000E00030@0001l000<10000iP0001D000<100007`000`40003V00005@000`40000O0003
0@000>H0000E00030@00020000<10000i@0001D000<1000080000`40003U00005@020B4000<10000
i@0001D000<1000080000`40003U00005@000`40000P00030@000>D0000E00030@00024000<10000
i00001D000<100008@000`40003T00005@000`40000Q00030@000>@00002008110000`4000030081
1@000`40000Q00030@000>@000001@01000100P000@1000110030B8000<10000h`00000500400040
20001040004400030@00028000<10000h`0000050040004020030@D000<100008P000`40003S0000
00D00@000@0800030@0000D000<100008P000`40003S000000D00@000@0800030@0000D000<10000
8P000`40003S00000P020@X00`4400030@0002<000<10000hP0001D000<100008`000`40003R0000
5@000`40000S00030@000>80000E008190000`40003R00005@000`40000T00030@000>40000E0003
0@0002@000<10000h@0001D000<1000090000`40003Q00005@000`40000T00030@000>40000E0003
0@0002@000<10000h@0001D000<100009@000`40003P00005@000`40000U00030@000>00000E0081
9P000`40003P00005@000`40000U00030@000>00000E00030@0002H000<10000g`0001D000<10000
9P000`40003O00005@000`40000V00030@000=l0000E00030@0002H000<10000g`0001D000<10000
9`000`40003N00005@020BP000<10000gP0001D000<100009`000`40003N00005@000`40000W0003
0@000=h0000E00030@0002P000<10000g@0001D000<10000:0000`40003M00005@000`40000X0003
0@000=d0000E00030@0002P000<10000g@0000800P4400030@0000<00P4500030@0002T000<10000
g00000050040004020001040004400<1:@000`40003L000000D00@000@0800040@000@@000<10000
:@000`40003L000000D00@000@0900811@000`40000Y00030@000=`000001@01000100P000@10001
10000`40000Z00030@000=/000001@01000100P000@1000110000`40000Z00030@000=/000020081
2P020@D000<10000:P000`40003K00005@000`40000Z00030@000=/0000E00030@0002/000<10000
fP0001D00P4/00030@000=X0000E00030@0002/000<10000fP0001D000<10000;0000`40003I0000
5@000`40000/00030@000=T0000E00030@0002`000<10000f@0001D000<10000;@000`40003H0000
5@000`40000]00030@000=P0000E0081;P000`40003H00005@000`40000]00030@000=P0000E0003
0@0002h000<10000e`0001D000<10000;P000`40003G00005@000`40000_00030@000=H0000E0003
0@0002l000<10000eP0001D000<10000<0000`40003E00005@000`40000`00030@000=D0000E0081
<P000`40003D00005@000`40000a00030@000=@0000E00030@00034000<100008P0=0JD0000E0003
0@00038000<100007P030@d00`6R00005@000`40000b00030@0001/00`4C00<1W`0001D000<10000
<P000`40000J00030@0001L00`6L00003@040@@000<10000<`000`40000G00817@020IX0000?0003
0@0000<000<10000<`000`40000F00030@0001l01P4R0281D00000l000<100000`030C@000<10000
4`020BP01@4D00T18P190@L0000?00030@0000<000<10000=@000`40000A00030@0002d0505k0000
3`000`40000300030@0003H000<100003P020Kl0000=00<11@000`40000f00030@0000`00P710000
3`000`40000300030@0003L00P4;00030@000<40000E00030@0003T000<100001@030L@0000E0003
0@0003X01`7700005@020Ol02P0001D000<10000o`0900005@000`40003o00T0000E00030@000?l0
2@000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, -0.0820738, 
  0.00385924, 0.00651625}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stepResponses = \ 
      Show[stepResponse1, \ stepResponse2, AxesLabel -> {"\<t\>", "\<\>"}]; 
    \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.531088 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -7.5 ]
[1.025 .01472 10 7.5 ]
[.01131 .12093 -18 -4.5 ]
[.01131 .12093 0 4.5 ]
[.01131 .22715 -18 -4.5 ]
[.01131 .22715 0 4.5 ]
[.01131 .33337 -18 -4.5 ]
[.01131 .33337 0 4.5 ]
[.01131 .43959 -18 -4.5 ]
[.01131 .43959 0 4.5 ]
[.01131 .5458 -6 -4.5 ]
[.01131 .5458 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t) show
69.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .12093 m
.03006 .12093 L
s
[(0.2)] .01131 .12093 1 0 Mshowa
.02381 .22715 m
.03006 .22715 L
s
[(0.4)] .01131 .22715 1 0 Mshowa
.02381 .33337 m
.03006 .33337 L
s
[(0.6)] .01131 .33337 1 0 Mshowa
.02381 .43959 m
.03006 .43959 L
s
[(0.8)] .01131 .43959 1 0 Mshowa
.02381 .5458 m
.03006 .5458 L
s
[(1)] .01131 .5458 1 0 Mshowa
.125 Mabswid
.02381 .04127 m
.02756 .04127 L
s
.02381 .06782 m
.02756 .06782 L
s
.02381 .09438 m
.02756 .09438 L
s
.02381 .14749 m
.02756 .14749 L
s
.02381 .17404 m
.02756 .17404 L
s
.02381 .2006 m
.02756 .2006 L
s
.02381 .2537 m
.02756 .2537 L
s
.02381 .28026 m
.02756 .28026 L
s
.02381 .30681 m
.02756 .30681 L
s
.02381 .35992 m
.02756 .35992 L
s
.02381 .38648 m
.02756 .38648 L
s
.02381 .41303 m
.02756 .41303 L
s
.02381 .46614 m
.02756 .46614 L
s
.02381 .49269 m
.02756 .49269 L
s
.02381 .51925 m
.02756 .51925 L
s
.02381 .57236 m
.02756 .57236 L
s
.02381 .59891 m
.02756 .59891 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01473 L
.03163 .01474 L
.03279 .01475 L
.03395 .01477 L
.0352 .01481 L
.03638 .01485 L
.03746 .0149 L
.03873 .01497 L
.04011 .01508 L
.04262 .01534 L
.04396 .01552 L
.04523 .01573 L
.04759 .01621 L
.05014 .0169 L
.0529 .01785 L
.05787 .02025 L
.06244 .02334 L
.0675 .02792 L
.07221 .03341 L
.08293 .05076 L
.09338 .07461 L
.10458 .10776 L
.14594 .28017 L
.16664 .37576 L
.18579 .45576 L
.20437 .5189 L
.21387 .54444 L
.22412 .56657 L
.22906 .57527 L
.23427 .58305 L
.2391 .58904 L
.24359 .59359 L
.24781 .59702 L
.25232 .59981 L
.25489 .60102 L
.25732 .60192 L
.2595 .60253 L
.26073 .6028 L
.26187 .60299 L
.26312 .60315 L
.26431 .60326 L
.26538 .60331 L
.26654 .60332 L
.2678 .60328 L
Mistroke
.26851 .60324 L
.26914 .60319 L
.27039 .60305 L
.27156 .60287 L
.27383 .60242 L
.27592 .60188 L
.28063 .60024 L
.28542 .59804 L
.29067 .59511 L
.30127 .5879 L
.32245 .57081 L
.34175 .55549 L
.35134 .54882 L
.36177 .54261 L
.37154 .5379 L
.38071 .53451 L
.38563 .5331 L
.39013 .53205 L
.39513 .53115 L
.39776 .53078 L
.40052 .53047 L
.40304 .53026 L
.40445 .53017 L
.40573 .5301 L
.40692 .53005 L
.40822 .53001 L
.40944 .52999 L
.41057 .52998 L
.41188 .52998 L
.41311 .53 L
.41381 .53001 L
.41446 .53003 L
.4159 .53008 L
.41729 .53014 L
.4188 .53023 L
.42154 .53042 L
.42638 .5309 L
.43092 .53147 L
.44129 .53316 L
.46229 .53758 L
.48074 .54169 L
.50095 .5456 L
.51062 .54709 L
.52096 .54836 L
.52668 .54891 L
.53188 .54933 L
.53711 .54966 L
.54205 .54989 L
.54667 .55005 L
.5493 .55012 L
Mistroke
.55176 .55016 L
.55309 .55018 L
.55435 .55019 L
.55548 .55019 L
.55671 .5502 L
.55742 .5502 L
.55805 .5502 L
.55879 .5502 L
.55948 .5502 L
.56071 .55019 L
.5614 .55018 L
.56204 .55018 L
.56426 .55015 L
.56632 .55011 L
.57101 .55001 L
.57559 .54986 L
.58049 .54967 L
.60174 .54855 L
.62187 .54731 L
.6401 .54627 L
.65048 .54577 L
.66022 .54538 L
.66974 .54507 L
.68001 .54483 L
.68535 .54474 L
.68826 .54471 L
.69097 .54468 L
.69349 .54465 L
.69577 .54464 L
.69831 .54462 L
.6997 .54462 L
.70102 .54461 L
.70218 .54461 L
.70342 .54461 L
.70459 .54461 L
.70566 .54461 L
.70691 .54461 L
.70761 .54461 L
.70827 .54461 L
.70947 .54461 L
.71075 .54462 L
.71354 .54463 L
.71616 .54465 L
.72105 .54468 L
.72992 .54478 L
.73951 .54491 L
.75911 .54522 L
.78058 .54558 L
.79047 .54572 L
.80106 .54585 L
Mistroke
.81098 .54595 L
.82014 .54602 L
.825 .54605 L
.83035 .54608 L
.83573 .5461 L
.83868 .54611 L
.84144 .54612 L
.84403 .54612 L
.84531 .54612 L
.8465 .54612 L
.84766 .54613 L
.84872 .54613 L
.84989 .54613 L
.85114 .54613 L
.85179 .54613 L
.85248 .54613 L
.85372 .54613 L
.85441 .54613 L
.85505 .54613 L
.85651 .54613 L
.85779 .54613 L
.85895 .54612 L
.86157 .54612 L
.86638 .54611 L
.87148 .5461 L
.88065 .54607 L
.90141 .54598 L
.91957 .5459 L
.93915 .54582 L
.94856 .54579 L
.95847 .54576 L
.96693 .54574 L
.97619 .54573 L
Mfstroke
[ ] 0 setdash
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01473 L
.03163 .01474 L
.03279 .01475 L
.03395 .01477 L
.0352 .0148 L
.03638 .01485 L
.03746 .01489 L
.03873 .01497 L
.04011 .01507 L
.04262 .01532 L
.04396 .0155 L
.04523 .0157 L
.04759 .01617 L
.05014 .01684 L
.0529 .01777 L
.05787 .02011 L
.06244 .02315 L
.0675 .02764 L
.07221 .03304 L
.08293 .05017 L
.09338 .07377 L
.10458 .10662 L
.14594 .27664 L
.16664 .36921 L
.18579 .44483 L
.20437 .50238 L
.21376 .52448 L
.22412 .54334 L
.22903 .55032 L
.23421 .55634 L
.23868 .56052 L
.24346 .56398 L
.24617 .5655 L
.24862 .56662 L
.25109 .56752 L
.25342 .56815 L
.25474 .56842 L
.25614 .56864 L
.25734 .56878 L
.25865 .56888 L
.25939 .56891 L
.26006 .56893 L
.26084 .56892 L
.26158 .56891 L
Mistroke
.26289 .56883 L
.26363 .56877 L
.26432 .5687 L
.26561 .56853 L
.26697 .5683 L
.26941 .56778 L
.27491 .56611 L
.27967 .56419 L
.28488 .56168 L
.3035 .55072 L
.32469 .53817 L
.33471 .53335 L
.34398 .52985 L
.34863 .52847 L
.35357 .5273 L
.35853 .52643 L
.36135 .52606 L
.36262 .52593 L
.364 .52581 L
.36512 .52572 L
.36632 .52565 L
.36758 .52559 L
.36876 .52556 L
.36994 .52553 L
.37104 .52552 L
.37204 .52553 L
.37312 .52555 L
.3743 .52558 L
.3756 .52563 L
.37696 .52571 L
.37823 .52579 L
.3805 .52598 L
.38294 .52624 L
.38821 .52698 L
.3931 .52786 L
.40415 .53042 L
.42427 .53627 L
.44449 .54231 L
.45441 .54491 L
.4635 .54696 L
.47216 .54857 L
.48164 .54992 L
.48658 .55045 L
.49118 .55084 L
.49603 .55114 L
.49875 .55126 L
.50002 .55131 L
.50122 .55134 L
.50242 .55137 L
.50352 .5514 L
Mistroke
.50474 .55142 L
.50606 .55143 L
.50732 .55144 L
.50803 .55144 L
.50869 .55144 L
.5099 .55144 L
.51118 .55142 L
.51238 .55141 L
.51367 .55139 L
.51601 .55133 L
.51829 .55126 L
.52038 .55118 L
.5252 .55095 L
.53049 .55063 L
.54117 .54981 L
.56233 .54784 L
.58161 .54609 L
.59119 .54535 L
.60161 .5447 L
.60638 .54446 L
.61145 .54424 L
.61588 .54409 L
.62054 .54395 L
.62288 .5439 L
.62544 .54385 L
.62779 .54382 L
.62992 .54379 L
.63114 .54378 L
.63245 .54377 L
.63318 .54377 L
.63385 .54376 L
.63516 .54376 L
.63629 .54376 L
.63752 .54376 L
.63882 .54376 L
.64003 .54376 L
.64116 .54377 L
.64239 .54377 L
.64464 .54379 L
.64682 .54381 L
.64884 .54384 L
.65343 .54391 L
.65831 .54401 L
.67978 .54462 L
.69997 .5453 L
.7184 .54585 L
.72885 .54609 L
.73859 .54627 L
.74355 .54634 L
.74825 .5464 L
Mistroke
.75084 .54642 L
.75366 .54644 L
.7562 .54646 L
.75858 .54647 L
.76111 .54648 L
.76246 .54649 L
.7639 .54649 L
.76462 .54649 L
.76541 .54649 L
.76616 .54649 L
.76685 .5465 L
.76815 .5465 L
.76888 .5465 L
.76954 .5465 L
.77085 .54649 L
.77205 .54649 L
.77336 .54649 L
.77475 .54649 L
.77709 .54648 L
.77966 .54647 L
.7849 .54644 L
.78986 .54641 L
.79917 .54632 L
.82008 .54609 L
.83829 .54589 L
.84866 .54579 L
.85839 .54571 L
.8679 .54565 L
.8728 .54562 L
.87816 .5456 L
.8835 .54558 L
.88641 .54558 L
.88912 .54557 L
.89042 .54557 L
.89166 .54557 L
.89278 .54557 L
.89397 .54557 L
.89527 .54557 L
.89646 .54556 L
.89775 .54556 L
.89848 .54556 L
.89916 .54556 L
.90041 .54556 L
.90111 .54556 L
.90175 .54556 L
.90298 .54557 L
.90414 .54557 L
.90675 .54557 L
.90956 .54557 L
.91471 .54558 L
Mistroke
.91944 .54559 L
.93798 .54565 L
.97619 .5458 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000?l0
8@000?l08@000?l08@000?l08@000?l08@0003h00P4400030@000080104R008110000`4000040003
0@0002400P4400030@0000<00P4R008110000`4000030081:0040AH0000m00040@000@P000<10000
8P001040004:00030@00020000@1000120001040004P00040@000@P000@10001:@000`40000E0000
?@001040004900030@00024000@100011`050B4000@1000120001040004P00040@000@P000@10001
:@000`40000E0000?@001040004:00030@00020000@100011`001040004R00040@000@P00`4Q0004
0@000@T00P4Z00030@0001D0000E00030@0002D000@100012`000`40000O00040@000@P000<10040
8P001040004800030@00024000@1000120001040004Y00030@0001D0000E00030@0002D000@10001
20001040004Q00040@000@T00P4R00040@000@P000<100008@001040004800040@000BL00`4G0000
5@000`40000V00812P020B<00P4;00030@0002400P4:00<18@020@X00P4Z00030@0000l00P440000
5@000`40003o008000@100010`0000l0o`410@X000<10000100001D000<100000`040@8000<10000
2@000`40000900030@0000T000<100002P000`40000900030@0000T000<100002@000`4000090003
0@0000T000<100002P000`40000900030@0000T000<100002@000`40000900030@0000T000<10000
2P000`40000900030@0000T000<100002@000`40000>00030@0000@0000E00030@0000L000<10000
8`000`40000^00030@0002h000<10000;@000`40000^00030@0000d0104400005@000`4000080003
0@000?H000<10000100001D000<1000020020OL000<10000100001D000<100002@000`40003l0000
5@000`40000:00030@000?/0000E00812`020O`0000E00030@0000/000<10000nP0001D000<10000
30000`40003i00005@000`40000<00030@000?T0000E00030@0000d000<10000n00001D000<10000
3@000`40003h00005@000`40000=00030@000?P0000E00813`000`40003g00005@000`40000>0003
0@000?L0000E00030@0000h00P7h00005@000`40000?00030@000?H0000E00030@0000l000<10000
mP0001D000<100003`000`40003f00005@020A4000<10000m@0001D000<1000040000`40003e0000
5@000`40000@0081mP0001D000<100004@000`40003d00005@000`40000A00030@000?@0000E0003
0@00014000<10000m00000800P4400030@000080104400030@00018000<10000l`00000500400040
20000`40000500814`000`40003c000000D00@000@0900030@0000@000<100004P000`40003c0000
00D00@000@0:00030@0000<000<100004P000`40003c000000D00@000@0;00030@00008000<10000
4`000`40003b000000D00@000@0800040@000@@000<100004`000`40003b00000P020@X00P450003
0@0001<000<10000lP0001D000<100004`000`40003b00005@020A@00P7c00005@000`40000D0003
0@000?40000E00030@0001@000<10000l@0001D000<1000050000`40003a00005@000`40000E0003
0@000?00000E00030@0001D000<10000l00001D000<100005@000`40003`00005@020AH000<10000
l00001D000<100005P000`40003_00005@000`40000F00030@000>l0000E00030@0001H000<10000
k`0001D000<100005P020O00000E00030@0001L000<10000kP0001D000<100005`000`40003^0000
5@020AP000<10000kP0001D000<100005`000`40003^00005@000`40000H00030@000>d0000E0003
0@0001P000<10000k@0001D000<1000060000`40003]00000P020@@000<1000010000`4000030003
0@0001P000<10000k@000005004000402P000`40000300816@020Nh000001@01000100L01@440003
0@0001T000<10000k0000005004000401`001040004500030@0001T000<10000k000000500400040
20000`400@0500030@0001T000<10000k0000005004000402@020@D000<100006P000`40003[0000
0P020@/000<100000`000`40000J00030@000>/0000E00030@0001X000<10000j`0001D00P4K0003
0@000>/0000E00030@0001X00P7/00005@000`40000J0081k00001D000<100006`000`40003Z0000
5@000`40000K00030@000>X0000E00030@0001`000<10000j@0001D000<1000070000`40003Y0000
5@020Ad000<10000j@0001D000<1000070000`40003Y00005@000`40000M00030@000>P0000E0003
0@0001d000<10000j00001D000<100007@000`40003X00005@000`40000M00030@000>P0000E0003
0@0001d000<10000j00001D00P4O00030@000>L0000E00030@0001h000<10000i`0001D000<10000
7P000`40003W00005@000`40000N00030@000>L0000E00030@0001l000<10000iP0000800P440003
0@0000<00P4500030@0001l000<10000iP00000500400040200010400044008180000`40003V0000
00D00@000@0800040@000@@000<100007`000`40003V000000D00@000@0800<11@000`40000O0003
0@000>H000001@01000100P000<100001@000`40000O0081i`0000050040004020000`4000050003
0@00020000<10000i@0000800P4:00<110000`40000P00030@000>D0000E00030@00020000<10000
i@0001D00P4Q00030@000>D0000E00030@00024000<10000i00001D000<100008@000`40003T0000
5@000`40000Q00030@000>@0000E00030@00024000<10000i00001D000<100008@020ND0000E0003
0@0002400P7U00005@020B<000<10000h`0001D000<100008P000`40003S00005@000`40000R0081
i00001D000<100008`000`40003R00005@000`40000S00030@000>80000E00030@0002<000<10000
hP0001D000<1000090000`40003Q00005@020B@00P7S00005@000`40000S0081h`0001D000<10000
90000`40003Q00005@000`40000T0081hP0001D000<100009@000`40003P00000P020@@000<10000
0`020@D000<100009@000`40003P000000D00@000@0800040@000@@000<100009@000`40003P0000
00D00@000@0800040@000@@00P4W00030@000=l000001@01000100T00P4500030@0002H000<10000
g`0000050040004020001040004400030@0002H000<10000g`000005004000402000104000440003
0@0002H00P7P00000P020@X00P4500030@0002H00P7P00005@000`40000V0081h00001D00P4X0081
g`0001D000<100009`020Ml0000E00030@0002L00P7O00005@000`40000Y00030@000=`0000E0003
0@0002T000<10000g00001D000<10000:@000`40003L00005@000`40000Z00030@000=/0000E0081
:P020Md0000E00030@0002T00P7M00005@000`40000Z0081g00001D000<10000:P020M`0000E0003
0@0002X00P7L00005@000`40000/00030@000=T0000E00030@0002`000<10000f@0001D00P4^0003
0@000=P0000E00030@0002d000<10000f00001D000<10000;0000`400@0Q00d1Z`0001D000<10000
;0000`400@0O00812P070@@00P6Q00005@000`40000]00030@0101/00`4C00@10P040Id0000=00@1
10000`40000]00030@0101T00P4:00813P020@P00P6G00003`000`40000300030@0002d000@10001
5P020@T00`4B00<11`040AX0704400@1E@0000l000<100000`020Bl000@100014`020@X000<10000
5P070@P0104700/100<00@40104500H11P1:0AL0000?00030@0000<000<10000<@000`40000@0003
0@0002X04`4200H1O00000l000<100000`000`40000b00030@0000d00P7400003@030@D000<10000
<`000`40000:00812`000`40002h00003`000`40000300030@0003@00P4800812`020K/0000E0003
0@00030000<100000`020@<00`4<00030@000;/0000E00030@00034000<1000010030@h000<10000
_00001D00P4b00030@000=@0000E00030@00038000<10000d`0001D000<10000<P000`40000@0003
0@000<00000E00030@0004D000<10000`00001D000<10000@`020L<0000E00030@0004400P750000
5@020CL000<10000c`0001D000<10000=`060L/0000E00030@000?l02@0001D000<10000o`090000
5@000`40003o00T0000E00030@000?l02@000?l08@000?l08@000?l08@000?l08@000?l08@000001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0871025, -0.128906, 
  0.00410959, 0.00736959}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Writing results to files", "Subsection"],

Cell[BoxData[
    \(\(Display["\<mag_4l.eps\>", magnitudeResponses, "\<EPS\>"]; \)\)], 
  "Input"],

Cell[BoxData[
    \(\(Display["\<phase_4l.eps\>", phaseResponses, "\<EPS\>"]; \)\)], "Input"],

Cell[BoxData[
    \(\(Display["\<step_4l.eps\>", stepResponses, "\<EPS\>"]; \)\)], "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
WindowSize->{520, 600},
WindowMargins->{{265, Automatic}, {134, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"Magnification"->1}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 45, 0, 107, "Title"],
Cell[1779, 53, 70, 3, 83, "Subtitle"],
Cell[1852, 58, 177, 5, 118, "Subsubtitle"],
Cell[2032, 65, 52, 0, 52, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2109, 69, 33, 0, 54, "Section"],
Cell[2145, 71, 65, 0, 32, "Text"],
Cell[2213, 73, 103, 2, 27, "Input",
  InitializationCell->True],
Cell[2319, 77, 60, 0, 32, "Text"],
Cell[2382, 79, 110, 2, 27, "Input",
  InitializationCell->True],
Cell[2495, 83, 103, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[2623, 90, 181, 3, 43, "Input",
  InitializationCell->True],
Cell[2807, 95, 174, 3, 39, "Message"],
Cell[2984, 100, 174, 3, 39, "Message"]
}, Closed]],
Cell[3173, 106, 117, 2, 24, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3327, 113, 69, 0, 34, "Section"],
Cell[3399, 115, 347, 6, 86, "Text"],
Cell[3749, 123, 419, 8, 86, "Text"],

Cell[CellGroupData[{
Cell[4193, 135, 74, 0, 45, "Subsection"],
Cell[4270, 137, 138, 3, 50, "Text"],
Cell[4411, 142, 85, 2, 43, "Input",
  InitializationCell->True],
Cell[4499, 146, 71, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[4595, 150, 172, 4, 43, "Input",
  InitializationCell->True],
Cell[4770, 156, 824, 22, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5631, 183, 169, 4, 43, "Input",
  InitializationCell->True],
Cell[5803, 189, 823, 22, 43, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6675, 217, 40, 0, 29, "Subsection"],

Cell[CellGroupData[{
Cell[6740, 221, 271, 5, 75, "Input",
  InitializationCell->True],
Cell[7014, 228, 11338, 405, 186, 4617, 317, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18389, 638, 224, 4, 59, "Input",
  InitializationCell->True],
Cell[18616, 644, 10781, 354, 186, 3746, 263, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29434, 1003, 185, 4, 43, "Input",
  InitializationCell->True],
Cell[29622, 1009, 13229, 492, 186, 6380, 403, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[42900, 1507, 36, 0, 29, "Subsection"],

Cell[CellGroupData[{
Cell[42961, 1511, 237, 5, 59, "Input",
  InitializationCell->True],
Cell[43201, 1518, 9693, 328, 186, 3417, 246, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52931, 1851, 200, 4, 43, "Input",
  InitializationCell->True],
Cell[53134, 1857, 9736, 323, 186, 3321, 239, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62907, 2185, 181, 4, 43, "Input",
  InitializationCell->True],
Cell[63091, 2191, 11573, 398, 186, 4860, 311, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[74713, 2595, 35, 0, 29, "Subsection"],

Cell[CellGroupData[{
Cell[74773, 2599, 248, 5, 59, "Input",
  InitializationCell->True],
Cell[75024, 2606, 12793, 482, 186, 5834, 392, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87854, 3093, 177, 3, 59, "Input"],
Cell[88034, 3098, 13491, 505, 186, 6106, 409, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101562, 3608, 165, 4, 43, "Input",
  InitializationCell->True],
Cell[101730, 3614, 17289, 730, 186, 10075, 636, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[119068, 4350, 46, 0, 29, "Subsection"],
Cell[119117, 4352, 98, 2, 27, "Input"],
Cell[119218, 4356, 93, 1, 27, "Input"],
Cell[119314, 4359, 91, 1, 27, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

