(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5200,        174]*)
(*NotebookOutlinePosition[      5865,        198]*)
(*  CellTagsIndexPosition[      5821,        194]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Generating Matlab Code to Optimize Analog Filter Designs", "Title"],

Cell["\<\
Niranjan Damera-Venkata and
Brian L. Evans\
\>", "Subtitle"],

Cell["\<\
Embedded Signal Processing Laboratory
Department of Electrical and Computer Engineering
The University of Texas at Austin
Austin, Texas 78712-1084\
\>", "Subsubtitle"],

Cell["http://anchovy.ece.utexas.edu", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell["Add the filter optimization packages to the path.", "Text"],

Cell[BoxData[
    \(\(AppendTo[$Path, \ "\<../Packages\>"]; \)\)], "Input",
  InitializationCell->True],

Cell["Initialize the filter optimization packages.", "Text"],

Cell[BoxData[
    \(\(Needs[\ "\<FilterOptimization`Master`\>"\ ]; \)\)], "Input",
  InitializationCell->True],

Cell["\<\
Clear several global variables.  You can ignore the two spell error \
warnings.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Clear[\ Wmp, \ Wmt, \ Wms, \ Wph, \ WQ, \ WO, \ a, \ b, \ c, \ d, \ 
      wp, \ ws, \ wmax, \ maxO, \ dp, \ ds\ ]; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(wmax\)\" is similar to \
existing symbol \"\!\(max\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(maxO\)\" is similar to \
existing symbol \"\!\(max\)\"."\)], "Message"]
}, Closed]],

Cell[BoxData[
    \(\(Begin["\<FilterOptimization`Generator`Private`\>"]; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: All-Pole Fourth-Order Case", "Section"],

Cell["\<\
The variable n represents the number of pole pairs, and m denotes \
the number of zero pairs in the analog filter.\
\>", "Text"],

Cell[BoxData[
    \(n\  = \ 2; \nm\  = \ 0; \)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The following command will generate the Matlab functions (",
  StyleBox["costderN.m",
    FontFamily->"Courier",
    FontSize->11],
  ", ",
  StyleBox["filtcostN.m",
    FontFamily->"Courier",
    FontSize->11],
  ", and ",
  StyleBox["stepresp.m",
    FontFamily->"Courier",
    FontSize->11],
  ", where ",
  StyleBox["N",
    FontFamily->"Courier",
    FontSize->11],
  " is replaced with the number of pole pairs n) and a Matlab script (",
  StyleBox["goN.m)",
    FontFamily->"Courier",
    FontSize->11],
  " to run the optimization.  For the all-pole case, the initial guess is a \
Butterworth filter.  The go script relies on the constr function in the \
Matlab Optimization Toolbox. Note that a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " file (",
  StyleBox["programN.m",
    FontFamily->"Courier",
    FontSize->11],
  ") that contains the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " formula for the overall cost function is also generated."
}], "Text"],

Cell[BoxData[
    \(MatlabOptimizationGen[\ {\ Wmp, \ Wmt, \ Wms, \ Wph, \ WQ, \ WO\ }, \n
      \t\t\ \ \ \ \ \ \ a, \ b, \ c, \ d, \ n, \ m, \ wp, \ ws, \ wmax, \ 
      maxO, \ dp, \ ds\ ]\)], "Input"],

Cell["\<\
The amount of time this program takes is exponential in n.  For an \
eighth-order filter (n=4) with eight zeroes (m=4), it takes four hours on a \
167 MHz Sun Ultra-2 workstation to generate the Matlab code.  We have \
generated sets of Matlab code for different cases in the release.\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
WindowSize->{520, 600},
WindowMargins->{{140, Automatic}, {Automatic, 41}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 73, 0, 201, "Title"],
Cell[1807, 53, 70, 3, 83, "Subtitle"],
Cell[1880, 58, 177, 5, 118, "Subsubtitle"],
Cell[2060, 65, 52, 0, 52, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2137, 69, 33, 0, 54, "Section"],
Cell[2173, 71, 65, 0, 32, "Text"],
Cell[2241, 73, 103, 2, 27, "Input",
  InitializationCell->True],
Cell[2347, 77, 60, 0, 32, "Text"],
Cell[2410, 79, 110, 2, 27, "Input",
  InitializationCell->True],
Cell[2523, 83, 103, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[2651, 90, 181, 3, 43, "Input",
  InitializationCell->True],
Cell[2835, 95, 174, 3, 39, "Message"],
Cell[3012, 100, 174, 3, 39, "Message"]
}, Closed]],
Cell[3201, 106, 117, 2, 24, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3355, 113, 54, 0, 34, "Section"],
Cell[3412, 115, 138, 3, 50, "Text"],
Cell[3553, 120, 85, 2, 43, "Input",
  InitializationCell->True],
Cell[3641, 124, 1013, 34, 122, "Text"],
Cell[4657, 160, 204, 3, 43, "Input"],
Cell[4864, 165, 308, 5, 86, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

